@@ -17,7 +17,6 @@ package org.eclipse.swt.tools.views;
 import javax.annotation.*;
 
 import org.eclipse.e4.ui.di.*;
-import org.eclipse.swt.*;
 import org.eclipse.swt.tools.internal.*;
 import org.eclipse.swt.widgets.*;
 
@@ -31,9 +30,9 @@ public class SleakView {
 
 	@PostConstruct
 	public void createPartControl(Composite parent) {
-		composite = new Composite(parent, SWT.NONE);
 		Sleak sleak = new Sleak ();
-		sleak.create(composite);
+		sleak.create(parent);
+		composite = parent;
 	}
 
 	@Focus
