@@ -15,7 +15,7 @@ package org.eclipse.swt.tools.internal;
 
 public interface JNIMethod extends JNIItem {
 
-	public static final String[] FLAGS = {FLAG_NO_GEN, FLAG_ADDRESS, FLAG_CONST, FLAG_DYNAMIC, FLAG_JNI, FLAG_CAST, FLAG_CPP, FLAG_NEW, FLAG_DELETE, FLAG_GCNEW, FLAG_OBJECT, FLAG_SETTER, FLAG_GETTER, FLAG_ADDER};
+	public static final String[] FLAGS = {FLAG_NO_GEN, FLAG_ADDRESS, FLAG_CONST, FLAG_DYNAMIC, FLAG_JNI, FLAG_CAST, FLAG_CPP, FLAG_NEW, FLAG_DELETE, FLAG_GCNEW, FLAG_OBJECT, FLAG_SETTER, FLAG_GETTER, FLAG_ADDER, FLAG_IGNORE_DEPRECATIONS};
 	
 public String getName();
 
