@@ -76,12 +76,13 @@ public void generate(JNIClass clazz) {
 	if (i == methods.length) return;
 	sort(methods);
 	generateNativeMacro(clazz);
+	generateWarningSettings();
 	generateExcludes(methods);
 	generate(methods);
 }
 
 public void generate(JNIMethod[] methods) {
-	sort(methods);	
+	sort(methods);
 	for (JNIMethod method : methods) {
 		if ((method.getModifiers() & Modifier.NATIVE) == 0) continue;
 		generate(method);
@@ -122,7 +123,7 @@ void generateCallback(JNIMethod method, String function) {
 		first = false;
 	}
 	outputln(") {");
-	
+
 	output("\t");
 	if (isStruct(flags[0]) || isFloatingPoint(types[0])) {
 		output(types[0]);
@@ -168,7 +169,7 @@ void generateCallback(JNIMethod method, String function) {
 		outputln("\treturn rc;");
 	}
 	outputln("}");
-	
+
 	output("static jlong ");
 	output(method.getName());
 	outputln("(jlong func) {");
@@ -183,7 +184,7 @@ void generateCallback(JNIMethod method, String function) {
 
 public void generate(JNIMethod method) {
 	if (method.getFlag(FLAG_NO_GEN)) return;
-	JNIType returnType = method.getReturnType();	
+	JNIType returnType = method.getReturnType();
 	if (!(returnType.isType("void") || returnType.isPrimitive() || isSystemClass(returnType) || returnType.isType("java.lang.String"))) {
 		output("Warning: bad return type. :");
 		outputln(method.toString());
@@ -250,6 +251,14 @@ void generateNativeMacro(JNIClass clazz) {
 	outputln();
 }
 
+void generateWarningSettings() {
+	outputln("#ifdef _WIN32");
+	outputln("  /* Many methods don't use their 'env' and 'that' arguments */");
+	outputln("  #pragma warning (disable: 4100)");
+	outputln("#endif");
+	outputln();
+}
+
 boolean generateGetParameter(JNIParameter param, boolean critical, int indent) {
 	JNIType paramType = param.getType();
 	if (paramType.isPrimitive() || isSystemClass(paramType)) return false;
