@@ -38,7 +38,7 @@ import org.eclipse.swt.widgets.*;
  * <p>Note that although this class is a subclass of <code>Composite</code>,
  * it does not make sense to add <code>Control</code> children to it,
  * or set a layout on it.
- * </p><p>
+ * </p>
  * <dl>
  *	<dt><b>Styles</b> <dd>BORDER
  *	<dt><b>Events</b> <dd>Dispose, Move, Resize
@@ -59,7 +59,7 @@ public class OleControlSite extends OleClientSite
 	// supporting Event Sink attributes
 	private OleEventSink[] oleEventSink = new OleEventSink[0];
 	private GUID[] oleEventSinkGUID = new GUID[0];
-	private long /*int*/[] oleEventSinkIUnknown = new long /*int*/[0];
+	private long[] oleEventSinkIUnknown = new long[0];
 
 	// supporting information for the Control COM object
 	private CONTROLINFO currentControlInfo;
@@ -133,21 +133,21 @@ public OleControlSite(Composite parent, int style, String progId) {
 		appClsid = getClassID(progId);
 		if (appClsid == null) OLE.error(OLE.ERROR_INVALID_CLASSID);
 
-		long /*int*/ licinfo = getLicenseInfo(appClsid);
+		long licinfo = getLicenseInfo(appClsid);
 		if (licinfo == 0) {
 
 			// Open a storage object
 			tempStorage = createTempStorage();
 
 			// Create ole object with storage object
-			long /*int*/[] address = new long /*int*/[1];
+			long[] address = new long[1];
 			/*
 			* Bug in ICA Client 2.7. The creation of the IOleObject fails if the client
 			* site is provided to OleCreate().  The fix is to detect that the program
 			* id is an ICA Client and do not pass a client site to OleCreate().
 			* IOleObject.SetClientSite() is called later on.
 			*/
-			long /*int*/ clientSite = isICAClient() ? 0 : iOleClientSite.getAddress();
+			long clientSite = isICAClient() ? 0 : iOleClientSite.getAddress();
 			int result = COM.OleCreate(appClsid, COM.IIDIUnknown, COM.OLERENDER_DRAW, null, clientSite, tempStorage.getAddress(), address);
 			if (result != COM.S_OK)
 				OLE.error(OLE.ERROR_CANNOT_CREATE_OBJECT, result);
@@ -156,7 +156,7 @@ public OleControlSite(Composite parent, int style, String progId) {
 
 		} else {
 			// Prepare the ClassFactory
-			long /*int*/[] ppvObject = new long /*int*/[1];
+			long[] ppvObject = new long[1];
 			try {
 				int result = COM.CoGetClassObject(appClsid, COM.CLSCTX_INPROC_HANDLER | COM.CLSCTX_INPROC_SERVER, 0, COM.IIDIClassFactory2, ppvObject);
 				if (result != COM.S_OK) {
@@ -164,7 +164,7 @@ public OleControlSite(Composite parent, int style, String progId) {
 				}
 				IClassFactory2 classFactory = new IClassFactory2(ppvObject[0]);
 				// Create Com Object
-				ppvObject = new long /*int*/[1];
+				ppvObject = new long[1];
 				result = classFactory.CreateInstanceLic(0, 0, COM.IIDIUnknown, licinfo, ppvObject);
 				classFactory.Release();
 				if (result != COM.S_OK)
@@ -176,7 +176,7 @@ public OleControlSite(Composite parent, int style, String progId) {
 			objIUnknown = new IUnknown(ppvObject[0]);
 
 			// Prepare a storage medium
-			ppvObject = new long /*int*/[1];
+			ppvObject = new long[1];
 			if (objIUnknown.QueryInterface(COM.IIDIPersistStorage, ppvObject) == COM.S_OK) {
 				IPersistStorage persist = new IPersistStorage(ppvObject[0]);
 				tempStorage = createTempStorage();
@@ -260,7 +260,7 @@ public void addEventListener(int eventID, OleListener listener) {
 }
 static GUID getDefaultEventSinkGUID(IUnknown unknown) {
 	// get Event Sink I/F from IProvideClassInfo2
-	long /*int*/[] ppvObject = new long /*int*/[1];
+	long[] ppvObject = new long[1];
 	if (unknown.QueryInterface(COM.IIDIProvideClassInfo2, ppvObject) == COM.S_OK) {
 		IProvideClassInfo2 pci2 = new IProvideClassInfo2(ppvObject[0]);
 		GUID riid = new GUID();
@@ -272,14 +272,14 @@ static GUID getDefaultEventSinkGUID(IUnknown unknown) {
 	// get Event Sink I/F from IProvideClassInfo
 	if (unknown.QueryInterface(COM.IIDIProvideClassInfo, ppvObject) == COM.S_OK) {
 		IProvideClassInfo pci = new IProvideClassInfo(ppvObject[0]);
-		long /*int*/[] ppTI = new long /*int*/[1];
-		long /*int*/[] ppEI = new long /*int*/[1];
+		long[] ppTI = new long[1];
+		long[] ppEI = new long[1];
 		int result = pci.GetClassInfo(ppTI);
 		pci.Release();
 
 		if (result == COM.S_OK && ppTI[0] != 0) {
 			ITypeInfo classInfo = new ITypeInfo(ppTI[0]);
-			long /*int*/[] ppTypeAttr = new long /*int*/[1];
+			long[] ppTypeAttr = new long[1];
 			result = classInfo.GetTypeAttr(ppTypeAttr);
 			if (result == COM.S_OK  && ppTypeAttr[0] != 0) {
 				TYPEATTR typeAttribute = new TYPEATTR();
@@ -304,7 +304,7 @@ static GUID getDefaultEventSinkGUID(IUnknown unknown) {
 
 			if (ppEI[0] != 0) {
 				ITypeInfo eventInfo = new ITypeInfo(ppEI[0]);
-				ppTypeAttr = new long /*int*/[1];
+				ppTypeAttr = new long[1];
 				result = eventInfo.GetTypeAttr(ppTypeAttr);
 				GUID riid = null;
 				if (result == COM.S_OK && ppTypeAttr[0] != 0) {
@@ -335,7 +335,7 @@ static GUID getDefaultEventSinkGUID(IUnknown unknown) {
  */
 public void addEventListener(OleAutomation automation, int eventID, OleListener listener) {
 	if (listener == null || automation == null) OLE.error (SWT.ERROR_NULL_ARGUMENT);
-	long /*int*/ address = automation.getAddress();
+	long address = automation.getAddress();
 	IUnknown unknown = new IUnknown(address);
 	GUID riid = getDefaultEventSinkGUID(unknown);
 	if (riid != null) {
@@ -359,7 +359,7 @@ public void addEventListener(OleAutomation automation, int eventID, OleListener
  */
 public void addEventListener(OleAutomation automation, String eventSinkId, int eventID, OleListener listener) {
 	if (listener == null || automation == null || eventSinkId == null) OLE.error (SWT.ERROR_NULL_ARGUMENT);
-	long /*int*/ address = automation.getAddress();
+	long address = automation.getAddress();
 	if (address == 0) return;
 	char[] buffer = (eventSinkId +"\0").toCharArray();
 	GUID guid = new GUID();
@@ -367,7 +367,7 @@ public void addEventListener(OleAutomation automation, String eventSinkId, int e
 	addEventListener(address, guid, eventID, listener);
 }
 
-void addEventListener(long /*int*/ iunknown, GUID guid, int eventID, OleListener listener) {
+void addEventListener(long iunknown, GUID guid, int eventID, OleListener listener) {
 	if (listener == null || iunknown == 0 || guid == null) OLE.error (SWT.ERROR_NULL_ARGUMENT);
 	// have we connected to this kind of event sink before?
 	int index = -1;
@@ -385,7 +385,7 @@ void addEventListener(long /*int*/ iunknown, GUID guid, int eventID, OleListener
 		int oldLength = oleEventSink.length;
 		OleEventSink[] newOleEventSink = new OleEventSink[oldLength + 1];
 		GUID[] newOleEventSinkGUID = new GUID[oldLength + 1];
-		long /*int*/[] newOleEventSinkIUnknown = new long /*int*/[oldLength + 1];
+		long[] newOleEventSinkIUnknown = new long[oldLength + 1];
 		System.arraycopy(oleEventSink, 0, newOleEventSink, 0, oldLength);
 		System.arraycopy(oleEventSinkGUID, 0, newOleEventSinkGUID, 0, oldLength);
 		System.arraycopy(oleEventSinkIUnknown, 0, newOleEventSinkIUnknown, 0, oldLength);
@@ -411,7 +411,7 @@ protected void addObjectReferences() {
 	connectPropertyChangeSink();
 
 	// Get access to the Control object
-	long /*int*/[] ppvObject = new long /*int*/[1];
+	long[] ppvObject = new long[1];
 	if (objIUnknown.QueryInterface(COM.IIDIOleControl, ppvObject) == COM.S_OK) {
 		IOleControl objIOleControl = new IOleControl(ppvObject[0]);
 		// ask the control for its info in case users
@@ -448,46 +448,45 @@ protected void createCOMInterfaces () {
 	// register each of the interfaces that this object implements
 	iOleControlSite = new COMObject(new int[]{2, 0, 0, 0, 1, 1, 3, 2, 1, 0}){
 		@Override
-		public long /*int*/ method0(long /*int*/[] args) {return QueryInterface(args[0], args[1]);}
+		public long method0(long[] args) {return QueryInterface(args[0], args[1]);}
 		@Override
-		public long /*int*/ method1(long /*int*/[] args) {return AddRef();}
+		public long method1(long[] args) {return AddRef();}
 		@Override
-		public long /*int*/ method2(long /*int*/[] args) {return Release();}
+		public long method2(long[] args) {return Release();}
 		@Override
-		public long /*int*/ method3(long /*int*/[] args) {return OnControlInfoChanged();}
+		public long method3(long[] args) {return OnControlInfoChanged();}
 		// method4 LockInPlaceActive - not implemented
 		// method5 GetExtendedControl - not implemented
 		// method6 TransformCoords - not implemented
 		// method7 Translate Accelerator - not implemented
 		@Override
-		public long /*int*/ method8(long /*int*/[] args) {return OnFocus((int)/*64*/args[0]);}
+		public long method8(long[] args) {return OnFocus((int)args[0]);}
 		// method9 ShowPropertyFrame - not implemented
 	};
 
 	iDispatch = new COMObject(new int[]{2, 0, 0, 1, 3, 5, 8}){
 		@Override
-		public long /*int*/ method0(long /*int*/[] args) {return QueryInterface(args[0], args[1]);}
+		public long method0(long[] args) {return QueryInterface(args[0], args[1]);}
 		@Override
-		public long /*int*/ method1(long /*int*/[] args) {return AddRef();}
+		public long method1(long[] args) {return AddRef();}
 		@Override
-		public long /*int*/ method2(long /*int*/[] args) {return Release();}
+		public long method2(long[] args) {return Release();}
 		// method3 GetTypeInfoCount - not implemented
 		// method4 GetTypeInfo - not implemented
 		// method5 GetIDsOfNames - not implemented
 		@Override
-		public long /*int*/ method6(long /*int*/[] args) {return Invoke((int)/*64*/args[0], args[1], (int)/*64*/args[2], (int)/*64*/args[3], args[4], args[5], args[6], args[7]);}
+		public long method6(long[] args) {return Invoke((int)args[0], args[1], (int)args[2], (int)args[3], args[4], args[5], args[6], args[7]);}
 	};
 }
 private void disconnectEventSinks() {
 
-	for (int i = 0; i < oleEventSink.length; i++) {
-		OleEventSink sink = oleEventSink[i];
+	for (OleEventSink sink : oleEventSink) {
 		sink.disconnect();
 		sink.Release();
 	}
 	oleEventSink = new OleEventSink[0];
 	oleEventSinkGUID = new GUID[0];
-	oleEventSinkIUnknown = new long /*int*/[0];
+	oleEventSinkIUnknown = new long[0];
 }
 private void disconnectPropertyChangeSink() {
 
@@ -520,7 +519,7 @@ public Color getBackground () {
 
 		if (varBackColor != null){
 			int[] colorRef = new int[1];
-			if (COM.OleTranslateColor(varBackColor.getInt(), getDisplay().hPalette, colorRef) == COM.S_OK)
+			if (COM.OleTranslateColor(varBackColor.getInt(), 0, colorRef) == COM.S_OK)
 				return Color.win32_new(getDisplay(), colorRef[0]);
 		}
 	}
@@ -568,26 +567,26 @@ public Color getForeground () {
 
 		if (varForeColor != null){
 			int[] colorRef = new int[1];
-			if (COM.OleTranslateColor(varForeColor.getInt(), getDisplay().hPalette, colorRef) == COM.S_OK)
+			if (COM.OleTranslateColor(varForeColor.getInt(), 0, colorRef) == COM.S_OK)
 				return Color.win32_new(getDisplay(), colorRef[0]);
 		}
 	}
 
 	return super.getForeground();
 }
-protected long /*int*/ getLicenseInfo(GUID clsid) {
-	long /*int*/[] ppvObject = new long /*int*/[1];
+protected long getLicenseInfo(GUID clsid) {
+	long[] ppvObject = new long[1];
 	if (COM.CoGetClassObject(clsid, COM.CLSCTX_INPROC_HANDLER
 				| COM.CLSCTX_INPROC_SERVER, 0, COM.IIDIClassFactory, ppvObject) != COM.S_OK) {
 		return 0;
 	}
-	long /*int*/ result = 0;
+	long result = 0;
 	IUnknown unknown = new IUnknown(ppvObject[0]);
 	if (unknown.QueryInterface(COM.IIDIClassFactory2, ppvObject) == COM.S_OK) {
 		IClassFactory2 classFactory = new IClassFactory2(ppvObject[0]);
 		LICINFO licinfo = new LICINFO();
 		if (classFactory.GetLicInfo(licinfo) == COM.S_OK) {
-			long /*int*/[] pBstrKey = new long /*int*/[1];
+			long[] pBstrKey = new long[1];
 			if (licinfo != null && licinfo.fRuntimeKeyAvail) {
 				if (classFactory.RequestLicKey(0, pBstrKey) == COM.S_OK) {
 					result = pBstrKey[0];
@@ -619,22 +618,22 @@ public Variant getSiteProperty(int dispId){
 	return null;
 }
 @Override
-protected int GetWindow(long /*int*/ phwnd) {
+protected int GetWindow(long phwnd) {
 
 	if (phwnd == 0)
 		return COM.E_INVALIDARG;
 	if (frame == null) {
-		OS.MoveMemory(phwnd, new long /*int*/[] {0}, C.PTR_SIZEOF);
+		OS.MoveMemory(phwnd, new long[] {0}, C.PTR_SIZEOF);
 		return COM.E_NOTIMPL;
 	}
 
 	// Copy the Window's handle into the memory passed in
-	OS.MoveMemory(phwnd, new long /*int*/[] {handle}, C.PTR_SIZEOF);
+	OS.MoveMemory(phwnd, new long[] {handle}, C.PTR_SIZEOF);
 	return COM.S_OK;
 }
-private int Invoke(int dispIdMember, long /*int*/ riid, int lcid, int dwFlags, long /*int*/ pDispParams, long /*int*/ pVarResult, long /*int*/ pExcepInfo, long /*int*/ pArgErr) {
+private int Invoke(int dispIdMember, long riid, int lcid, int dwFlags, long pDispParams, long pVarResult, long pExcepInfo, long pArgErr) {
 	if (pVarResult == 0 || dwFlags != COM.DISPATCH_PROPERTYGET) {
-		if (pExcepInfo != 0) OS.MoveMemory(pExcepInfo, new long /*int*/ [] {0}, C.PTR_SIZEOF);
+		if (pExcepInfo != 0) OS.MoveMemory(pExcepInfo, new long [] {0}, C.PTR_SIZEOF);
 		if (pArgErr != 0) OS.MoveMemory(pArgErr, new int[] {0}, 4);
 		return COM.DISP_E_MEMBERNOTFOUND;
 	}
@@ -648,8 +647,8 @@ private int Invoke(int dispIdMember, long /*int*/ riid, int lcid, int dwFlags, l
 		case COM.DISPID_AMBIENT_SUPPORTSMNEMONICS :
 		case COM.DISPID_AMBIENT_SHOWGRABHANDLES :
 		case COM.DISPID_AMBIENT_SHOWHATCHING :
-			if (pVarResult != 0) OS.MoveMemory(pVarResult, new long /*int*/ [] {0}, C.PTR_SIZEOF);
-			if (pExcepInfo != 0) OS.MoveMemory(pExcepInfo, new long /*int*/ [] {0}, C.PTR_SIZEOF);
+			if (pVarResult != 0) OS.MoveMemory(pVarResult, new long [] {0}, C.PTR_SIZEOF);
+			if (pExcepInfo != 0) OS.MoveMemory(pExcepInfo, new long [] {0}, C.PTR_SIZEOF);
 			if (pArgErr != 0) OS.MoveMemory(pArgErr, new int[] {0}, 4);
 			return COM.S_FALSE;
 
@@ -661,20 +660,20 @@ private int Invoke(int dispIdMember, long /*int*/ riid, int lcid, int dwFlags, l
 		case COM.DISPID_AMBIENT_LOCALEID :
 		case COM.DISPID_AMBIENT_SILENT :
 		case COM.DISPID_AMBIENT_MESSAGEREFLECT :
-			if (pVarResult != 0) OS.MoveMemory(pVarResult, new long /*int*/ [] {0}, C.PTR_SIZEOF);
-			if (pExcepInfo != 0) OS.MoveMemory(pExcepInfo, new long /*int*/ [] {0}, C.PTR_SIZEOF);
+			if (pVarResult != 0) OS.MoveMemory(pVarResult, new long [] {0}, C.PTR_SIZEOF);
+			if (pExcepInfo != 0) OS.MoveMemory(pExcepInfo, new long [] {0}, C.PTR_SIZEOF);
 			if (pArgErr != 0) OS.MoveMemory(pArgErr, new int[] {0}, 4);
 			return COM.E_NOTIMPL;
 
 		default :
-			if (pVarResult != 0) OS.MoveMemory(pVarResult, new long /*int*/ [] {0}, C.PTR_SIZEOF);
-			if (pExcepInfo != 0) OS.MoveMemory(pExcepInfo,new long /*int*/ [] {0}, C.PTR_SIZEOF);
+			if (pVarResult != 0) OS.MoveMemory(pVarResult, new long [] {0}, C.PTR_SIZEOF);
+			if (pExcepInfo != 0) OS.MoveMemory(pExcepInfo,new long [] {0}, C.PTR_SIZEOF);
 			if (pArgErr != 0) OS.MoveMemory(pArgErr, new int[] {0}, 4);
 			return COM.DISP_E_MEMBERNOTFOUND;
 	}
 }
 private int OnControlInfoChanged() {
-	long /*int*/[] ppvObject = new long /*int*/[1];
+	long[] ppvObject = new long[1];
 	if (objIUnknown.QueryInterface(COM.IIDIOleControl, ppvObject) == COM.S_OK) {
 		IOleControl objIOleControl = new IOleControl(ppvObject[0]);
 		// ask the control for its info in case users
@@ -700,7 +699,7 @@ void onFocusIn(Event e) {
 	if (objIOleInPlaceObject == null) return;
 	if (!isActivated) doVerb(OLE.OLEIVERB_UIACTIVATE);
 	if (isFocusControl()) return;
-	long /*int*/[] phwnd = new long /*int*/[1];
+	long[] phwnd = new long[1];
 	objIOleInPlaceObject.GetWindow(phwnd);
 	if (phwnd[0] == 0) return;
 	OS.SetFocus(phwnd[0]);
@@ -763,7 +762,7 @@ private int OnFocus(int fGotFocus) {
 	return COM.S_OK;
 }
 @Override
-protected int QueryInterface(long /*int*/ riid, long /*int*/ ppvObject) {
+protected int QueryInterface(long riid, long ppvObject) {
 	int result = super.QueryInterface(riid, ppvObject);
 	if (result == COM.S_OK)
 		return result;
@@ -772,16 +771,16 @@ protected int QueryInterface(long /*int*/ riid, long /*int*/ ppvObject) {
 	GUID guid = new GUID();
 	COM.MoveMemory(guid, riid, GUID.sizeof);
 	if (COM.IsEqualGUID(guid, COM.IIDIOleControlSite)) {
-		OS.MoveMemory(ppvObject, new long /*int*/[] {iOleControlSite.getAddress()}, C.PTR_SIZEOF);
+		OS.MoveMemory(ppvObject, new long[] {iOleControlSite.getAddress()}, C.PTR_SIZEOF);
 		AddRef();
 		return COM.S_OK;
 	}
 	if (COM.IsEqualGUID(guid, COM.IIDIDispatch)) {
-		OS.MoveMemory(ppvObject, new long /*int*/[] {iDispatch.getAddress()}, C.PTR_SIZEOF);
+		OS.MoveMemory(ppvObject, new long[] {iDispatch.getAddress()}, C.PTR_SIZEOF);
 		AddRef();
 		return COM.S_OK;
 	}
-	OS.MoveMemory(ppvObject, new long /*int*/[] {0}, C.PTR_SIZEOF);
+	OS.MoveMemory(ppvObject, new long[] {0}, C.PTR_SIZEOF);
 	return COM.E_NOINTERFACE;
 }
 @Override
@@ -865,14 +864,14 @@ public void removeEventListener(OleAutomation automation, GUID guid, int eventID
 public void removeEventListener(OleAutomation automation, int eventID, OleListener listener) {
 	checkWidget();
 	if (automation == null || listener == null) SWT.error (SWT.ERROR_NULL_ARGUMENT);
-	long /*int*/ address = automation.getAddress();
+	long address = automation.getAddress();
 	IUnknown unknown = new IUnknown(address);
 	GUID riid = getDefaultEventSinkGUID(unknown);
 	if (riid != null) {
 		removeEventListener(address, riid, eventID, listener);
 	}
 }
-void removeEventListener(long /*int*/ iunknown, GUID guid, int eventID, OleListener listener) {
+void removeEventListener(long iunknown, GUID guid, int eventID, OleListener listener) {
 	if (listener == null || guid == null) SWT.error (SWT.ERROR_NULL_ARGUMENT);
 	for (int i = 0; i < oleEventSink.length; i++) {
 		if (COM.IsEqualGUID(oleEventSinkGUID[i], guid)) {
@@ -886,7 +885,7 @@ void removeEventListener(long /*int*/ iunknown, GUID guid, int eventID, OleListe
 					if (oldLength == 1) {
 						oleEventSink = new OleEventSink[0];
 						oleEventSinkGUID = new GUID[0];
-						oleEventSinkIUnknown = new long /*int*/[0];
+						oleEventSinkIUnknown = new long[0];
 					} else {
 						OleEventSink[] newOleEventSink = new OleEventSink[oldLength - 1];
 						System.arraycopy(oleEventSink, 0, newOleEventSink, 0, i);
@@ -898,7 +897,7 @@ void removeEventListener(long /*int*/ iunknown, GUID guid, int eventID, OleListe
 						System.arraycopy(oleEventSinkGUID, i + 1, newOleEventSinkGUID, i, oldLength - i - 1);
 						oleEventSinkGUID = newOleEventSinkGUID;
 
-						long /*int*/[] newOleEventSinkIUnknown = new long /*int*/[oldLength - 1];
+						long[] newOleEventSinkIUnknown = new long[oldLength - 1];
 						System.arraycopy(oleEventSinkIUnknown, 0, newOleEventSinkIUnknown, 0, i);
 						System.arraycopy(oleEventSinkIUnknown, i + 1, newOleEventSinkIUnknown, i, oldLength - i - 1);
 						oleEventSinkIUnknown = newOleEventSinkIUnknown;
