@@ -13,13 +13,9 @@
 #     IBM Corporation - initial API and implementation
 #*******************************************************************************
 
-cd `dirname $0`
+sw_vers -productVersion
 
-if [ -d /System/Library/Frameworks/JavaVM.framework/Headers ]; then
-	export CFLAGS_JAVA_VM="-I /System/Library/Frameworks/JavaVM.framework/Headers"
-else
-	export CFLAGS_JAVA_VM="-I $(/usr/libexec/java_home)/include -I $(/usr/libexec/java_home)/include/darwin"
-fi
+cd `dirname $0`
 
 if [ "x${MODEL}" = "xx86_64" ]; then
 	export ARCHS="-arch x86_64"
