@@ -19,7 +19,7 @@ public NSColorList() {
 	super();
 }
 
-public NSColorList(long /*int*/ id) {
+public NSColorList(long id) {
 	super(id);
 }
 
@@ -28,26 +28,26 @@ public NSColorList(id id) {
 }
 
 public NSArray allKeys() {
-	long /*int*/ result = OS.objc_msgSend(this.id, OS.sel_allKeys);
+	long result = OS.objc_msgSend(this.id, OS.sel_allKeys);
 	return result != 0 ? new NSArray(result) : null;
 }
 
 public static NSColorList colorListNamed(NSString name) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSColorList, OS.sel_colorListNamed_, name != null ? name.id : 0);
+	long result = OS.objc_msgSend(OS.class_NSColorList, OS.sel_colorListNamed_, name != null ? name.id : 0);
 	return result != 0 ? new NSColorList(result) : null;
 }
 
 public NSColor colorWithKey(NSString key) {
-	long /*int*/ result = OS.objc_msgSend(this.id, OS.sel_colorWithKey_, key != null ? key.id : 0);
+	long result = OS.objc_msgSend(this.id, OS.sel_colorWithKey_, key != null ? key.id : 0);
 	return result != 0 ? new NSColor(result) : null;
 }
 
 public NSColorList initWithName(NSString name) {
-	long /*int*/ result = OS.objc_msgSend(this.id, OS.sel_initWithName_, name != null ? name.id : 0);
+	long result = OS.objc_msgSend(this.id, OS.sel_initWithName_, name != null ? name.id : 0);
 	return result == this.id ? this : (result != 0 ? new NSColorList(result) : null);
 }
 
-public void insertColor(NSColor color, NSString key, long /*int*/ loc) {
+public void insertColor(NSColor color, NSString key, long loc) {
 	OS.objc_msgSend(this.id, OS.sel_insertColor_key_atIndex_, color != null ? color.id : 0, key != null ? key.id : 0, loc);
 }
 
