@@ -19,7 +19,7 @@ public NSGradient() {
 	super();
 }
 
-public NSGradient(long /*int*/ id) {
+public NSGradient(long id) {
 	super(id);
 }
 
@@ -27,25 +27,25 @@ public NSGradient(id id) {
 	super(id);
 }
 
-public void drawFromPoint(NSPoint startingPoint, NSPoint endingPoint, long /*int*/ options) {
+public void drawFromPoint(NSPoint startingPoint, NSPoint endingPoint, long options) {
 	OS.objc_msgSend(this.id, OS.sel_drawFromPoint_toPoint_options_, startingPoint, endingPoint, options);
 }
 
-public void drawInBezierPath(NSBezierPath path, double /*float*/ angle) {
+public void drawInBezierPath(NSBezierPath path, double angle) {
 	OS.objc_msgSend(this.id, OS.sel_drawInBezierPath_angle_, path != null ? path.id : 0, angle);
 }
 
-public void drawInRect(NSRect rect, double /*float*/ angle) {
+public void drawInRect(NSRect rect, double angle) {
 	OS.objc_msgSend(this.id, OS.sel_drawInRect_angle_, rect, angle);
 }
 
 public NSGradient initWithColors(NSArray colorArray) {
-	long /*int*/ result = OS.objc_msgSend(this.id, OS.sel_initWithColors_, colorArray != null ? colorArray.id : 0);
+	long result = OS.objc_msgSend(this.id, OS.sel_initWithColors_, colorArray != null ? colorArray.id : 0);
 	return result == this.id ? this : (result != 0 ? new NSGradient(result) : null);
 }
 
 public NSGradient initWithStartingColor(NSColor startingColor, NSColor endingColor) {
-	long /*int*/ result = OS.objc_msgSend(this.id, OS.sel_initWithStartingColor_endingColor_, startingColor != null ? startingColor.id : 0, endingColor != null ? endingColor.id : 0);
+	long result = OS.objc_msgSend(this.id, OS.sel_initWithStartingColor_endingColor_, startingColor != null ? startingColor.id : 0, endingColor != null ? endingColor.id : 0);
 	return result == this.id ? this : (result != 0 ? new NSGradient(result) : null);
 }
 
