@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -45,6 +45,10 @@ public NSMutableArray initWithCapacity(long numItems) {
 	return result == this.id ? this : (result != 0 ? new NSMutableArray(result) : null);
 }
 
+public void insertObject(id anObject, long index) {
+	OS.objc_msgSend(this.id, OS.sel_insertObject_atIndex_, anObject != null ? anObject.id : 0, index);
+}
+
 public void removeLastObject() {
 	OS.objc_msgSend(this.id, OS.sel_removeLastObject);
 }
