@@ -19,7 +19,7 @@ public NSNumber() {
 	super();
 }
 
-public NSNumber(long /*int*/ id) {
+public NSNumber(long id) {
 	super(id);
 }
 
@@ -40,50 +40,50 @@ public float floatValue() {
 }
 
 public int intValue() {
-	return (int)/*64*/OS.objc_msgSend(this.id, OS.sel_intValue);
+	return (int)OS.objc_msgSend(this.id, OS.sel_intValue);
 }
 
-public long /*int*/ integerValue() {
+public long integerValue() {
 	return OS.objc_msgSend(this.id, OS.sel_integerValue);
 }
 
 public static NSNumber numberWithBool(boolean value) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_numberWithBool_, value);
+	long result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_numberWithBool_, value);
 	return result != 0 ? new NSNumber(result) : null;
 }
 
 public static NSNumber numberWithDouble(double value) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_numberWithDouble_, value);
+	long result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_numberWithDouble_, value);
 	return result != 0 ? new NSNumber(result) : null;
 }
 
 public static NSNumber numberWithInt(int value) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_numberWithInt_, value);
+	long result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_numberWithInt_, value);
 	return result != 0 ? new NSNumber(result) : null;
 }
 
-public static NSNumber numberWithInteger(long /*int*/ value) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_numberWithInteger_, value);
+public static NSNumber numberWithInteger(long value) {
+	long result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_numberWithInteger_, value);
 	return result != 0 ? new NSNumber(result) : null;
 }
 
 public static NSValue valueWithPoint(NSPoint point) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_valueWithPoint_, point);
+	long result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_valueWithPoint_, point);
 	return result != 0 ? new NSValue(result) : null;
 }
 
 public static NSValue valueWithRange(NSRange range) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_valueWithRange_, range);
+	long result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_valueWithRange_, range);
 	return result != 0 ? new NSValue(result) : null;
 }
 
 public static NSValue valueWithRect(NSRect rect) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_valueWithRect_, rect);
+	long result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_valueWithRect_, rect);
 	return result != 0 ? new NSValue(result) : null;
 }
 
 public static NSValue valueWithSize(NSSize size) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_valueWithSize_, size);
+	long result = OS.objc_msgSend(OS.class_NSNumber, OS.sel_valueWithSize_, size);
 	return result != 0 ? new NSValue(result) : null;
 }
 
