@@ -19,7 +19,7 @@ public NSPrintOperation() {
 	super();
 }
 
-public NSPrintOperation(long /*int*/ id) {
+public NSPrintOperation(long id) {
 	super(id);
 }
 
@@ -32,12 +32,12 @@ public void cleanUpOperation() {
 }
 
 public NSGraphicsContext context() {
-	long /*int*/ result = OS.objc_msgSend(this.id, OS.sel_context);
+	long result = OS.objc_msgSend(this.id, OS.sel_context);
 	return result != 0 ? new NSGraphicsContext(result) : null;
 }
 
 public NSGraphicsContext createContext() {
-	long /*int*/ result = OS.objc_msgSend(this.id, OS.sel_createContext);
+	long result = OS.objc_msgSend(this.id, OS.sel_createContext);
 	return result != 0 ? new NSGraphicsContext(result) : null;
 }
 
@@ -50,7 +50,7 @@ public void destroyContext() {
 }
 
 public static NSPrintOperation printOperationWithView(NSView view, NSPrintInfo printInfo) {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_printOperationWithView_printInfo_, view != null ? view.id : 0, printInfo != null ? printInfo.id : 0);
+	long result = OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_printOperationWithView_printInfo_, view != null ? view.id : 0, printInfo != null ? printInfo.id : 0);
 	return result != 0 ? new NSPrintOperation(result) : null;
 }
 
