@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2012 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -19,7 +19,7 @@ public NSRunLoop() {
 	super();
 }
 
-public NSRunLoop(long /*int*/ id) {
+public NSRunLoop(long id) {
 	super(id);
 }
 
@@ -32,12 +32,7 @@ public void addTimer(NSTimer timer, NSString mode) {
 }
 
 public static NSRunLoop currentRunLoop() {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSRunLoop, OS.sel_currentRunLoop);
-	return result != 0 ? new NSRunLoop(result) : null;
-}
-
-public static NSRunLoop mainRunLoop() {
-	long /*int*/ result = OS.objc_msgSend(OS.class_NSRunLoop, OS.sel_mainRunLoop);
+	long result = OS.objc_msgSend(OS.class_NSRunLoop, OS.sel_currentRunLoop);
 	return result != 0 ? new NSRunLoop(result) : null;
 }
 
