@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -35,9 +35,4 @@ public void setTextColor(NSColor textColor) {
 	OS.objc_msgSend(this.id, OS.sel_setTextColor_, textColor != null ? textColor.id : 0);
 }
 
-public NSColor textColor() {
-	long result = OS.objc_msgSend(this.id, OS.sel_textColor);
-	return result != 0 ? new NSColor(result) : null;
-}
-
 }
