@@ -1,9 +1,12 @@
 /*******************************************************************************
  * Copyright (c) 2000, 2012 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -15,8 +18,8 @@ public class ICONINFO {
 	public int xHotspot;
 	public int yHotspot;
 	/** @field cast=(HBITMAP) */
-	public long /*int*/ hbmMask;
+	public long hbmMask;
 	/** @field cast=(HBITMAP) */
-	public long /*int*/ hbmColor;
+	public long hbmColor;
 	public static final int sizeof = OS.ICONINFO_sizeof ();
 }
