@@ -1,9 +1,12 @@
 /*******************************************************************************
  * Copyright (c) 2000, 2012 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -13,7 +16,7 @@ package org.eclipse.swt.internal.win32;
 public class NMREBARCHEVRON extends NMHDR {
 	public int uBand;
 	public int wID;
-	public long /*int*/ lParam;
+	public long lParam;
 //	RECT rc;
 	/** @field accessor=rc.left */
 	public int left;
@@ -23,6 +26,6 @@ public class NMREBARCHEVRON extends NMHDR {
 	public int right;
 	/** @field accessor=rc.bottom */
 	public int bottom;
-	public long /*int*/ lParamNM;
+	public long lParamNM;
 	public static int sizeof = OS.NMREBARCHEVRON_sizeof ();
 }
