@@ -19,4 +19,15 @@ public class RECT {
 	public int right;
 	public int bottom;
 	public static final int sizeof = OS.RECT_sizeof ();
+
+	public RECT() {
+
+	}
+
+	public RECT(int left, int top, int right, int bottom) {
+		this.left = left;
+		this.top = top;
+		this.right = right;
+		this.bottom = bottom;
+	}
 }
