@@ -23,7 +23,8 @@ import org.eclipse.swt.*;
 import org.eclipse.swt.graphics.*;
 import org.eclipse.swt.internal.*;
 import org.eclipse.swt.internal.gtk.*;
-import org.eclipse.swt.widgets.*;
+import org.eclipse.swt.internal.gtk3.*;
+import org.eclipse.swt.internal.gtk4.*;
 
 /**
  * Instances of this class represent programs and
@@ -37,7 +38,6 @@ public final class Program {
 	String name = ""; //$NON-NLS-1$
 	String command;
 	String iconPath;
-	Display display;
 
 	/* GIO specific
 	 * true if command expects a URI
@@ -112,31 +112,12 @@ static String[] parseCommand(String cmd) {
  *	</ul>
  */
 public static Program findProgram(String extension) {
-	return findProgram(Display.getCurrent(), extension);
-}
-
-/*
- *  API: When support for multiple displays is added, this method will
- *       become public and the original method above can be deprecated.
- */
-static Program findProgram(Display display, String extension) {
 	if (extension == null) SWT.error(SWT.ERROR_NULL_ARGUMENT);
 	if (extension.length() == 0) return null;
 	if (extension.charAt(0) != '.') extension = "." + extension;
 	String mimeType = gio_getMimeType(extension);
 	if (mimeType == null) return null;
-	return gio_getProgram(display, mimeType);
-}
-
-/**
- * Answers all available programs in the operating system.  Note
- * that a <code>Display</code> must already exist to guarantee
- * that this method returns an appropriate result.
- *
- * @return an array of programs
- */
-public static Program[] getPrograms() {
-	return getPrograms(Display.getCurrent());
+	return gio_getProgram(mimeType);
 }
 
 /**
@@ -149,52 +130,72 @@ public static Program[] getPrograms() {
 public ImageData getImageData() {
 	if (iconPath == null) return null;
 	ImageData data = null;
-	long icon_theme;
-	if (GTK.GTK4) {
-		icon_theme = GTK.gtk_icon_theme_get_for_display(GDK.gdk_display_get_default());
-	} else {
-		icon_theme = GTK.gtk_icon_theme_get_default();
+
+	long gicon = OS.g_icon_new_for_string(Converter.javaStringToCString(iconPath), null);
+	if (gicon != 0) {
+		long pixbuf = 0;
+		if (GTK.GTK4) {
+			/*
+			 * Specified size will not be respected as in order to get the pixbuf,
+			 * we get the original image file which could be any size. Also, note
+			 * that gtk_icon_theme_lookup_by_gicon never returns NULL, it will
+			 * return a error icon if gicon can't be found.
+			 */
+			long icon_theme = GTK4.gtk_icon_theme_get_for_display(GDK.gdk_display_get_default()); // default display needs to exist
+			long paintable = GTK4.gtk_icon_theme_lookup_by_gicon(icon_theme, gicon, 16, 1, GTK.GTK_TEXT_DIR_NONE, GTK.GTK_ICON_LOOKUP_FORCE_REGULAR);
+			long file = GTK4.gtk_icon_paintable_get_file(paintable);
+			long texture = GDK.gdk_texture_new_from_file(file, 0);
+			pixbuf = GDK.gdk_pixbuf_get_from_texture(texture);
+
+			OS.g_object_unref(texture);
+			OS.g_object_unref(file);
+			OS.g_object_unref(paintable);
+		} else {
+			long icon_theme = GTK3.gtk_icon_theme_get_default();
+			long gicon_info = GTK3.gtk_icon_theme_lookup_by_gicon(icon_theme, gicon, 16/*size*/, 0);
+			if (gicon_info != 0) {
+				pixbuf = GTK3.gtk_icon_info_load_icon(gicon_info, null);
+				OS.g_object_unref(gicon_info);
+			}
+		}
+
+		// Unref gicon as we have retrieved the required pixbuf
+		OS.g_object_unref(gicon);
+
+		if (pixbuf != 0) {
+			int stride = GDK.gdk_pixbuf_get_rowstride(pixbuf);
+			long pixels = GDK.gdk_pixbuf_get_pixels(pixbuf);
+			int height = GDK.gdk_pixbuf_get_height(pixbuf);
+			int width = GDK.gdk_pixbuf_get_width(pixbuf);
+			boolean hasAlpha = GDK.gdk_pixbuf_get_has_alpha(pixbuf);
+
+			// Move pixbuf memory to srcData and unref pixbuf
+			byte[] srcData = new byte[stride * height];
+			C.memmove(srcData, pixels, srcData.length);
+			OS.g_object_unref(pixbuf);
+
+			if (hasAlpha) {
+				PaletteData palette = new PaletteData(0xFF000000, 0xFF0000, 0xFF00);
+				data = new ImageData(width, height, 32, palette, 4, srcData);
+				data.bytesPerLine = stride;
+				int s = 3, a = 0;
+				byte[] alphaData = new byte[width * height];
+				for (int y = 0; y < height; y++) {
+					for (int x = 0; x < width; x++) {
+						alphaData[a++] = srcData[s];
+						srcData[s] = 0;
+						s+=4;
+					}
+				}
+				data.alphaData = alphaData;
+			} else {
+				PaletteData palette = new PaletteData(0xFF0000, 0xFF00, 0xFF);
+				data = new ImageData(width, height, 24, palette, 4, srcData);
+				data.bytesPerLine = stride;
+			}
+		}
 	}
 
-	byte[] icon = Converter.wcsToMbcs (iconPath, true);
-	long gicon = OS.g_icon_new_for_string(icon, null);
-	if (gicon != 0) {
-		long gicon_info = GTK.gtk_icon_theme_lookup_by_gicon (icon_theme, gicon, 16/*size*/, 0);
-		if (gicon_info != 0) {
-			long pixbuf = GTK.gtk_icon_info_load_icon(gicon_info, null);
-			if (pixbuf != 0) {
-				int stride = GDK.gdk_pixbuf_get_rowstride(pixbuf);
-				long pixels = GDK.gdk_pixbuf_get_pixels(pixbuf);
-				int height = GDK.gdk_pixbuf_get_height(pixbuf);
-				int width = GDK.gdk_pixbuf_get_width(pixbuf);
-				boolean hasAlpha = GDK.gdk_pixbuf_get_has_alpha(pixbuf);
-				byte[] srcData = new byte[stride * height];
-				C.memmove(srcData, pixels, srcData.length);
-				OS.g_object_unref(pixbuf);
-				if (hasAlpha) {
-					PaletteData palette = new PaletteData(0xFF000000, 0xFF0000, 0xFF00);
-					data = new ImageData(width, height, 32, palette, 4, srcData);
-					data.bytesPerLine = stride;
-					int s = 3, a = 0;
-					byte[] alphaData = new byte[width*height];
-					for (int y=0; y<height; y++) {
-						for (int x=0; x<width; x++) {
-							alphaData[a++] = srcData[s];
-							srcData[s] = 0;
-							s+=4;
-						}
-					}
-					data.alphaData = alphaData;
-				} else {
-					PaletteData palette = new PaletteData(0xFF0000, 0xFF00, 0xFF);
-					data = new ImageData(width, height, 24, palette, 4, srcData);
-					data.bytesPerLine = stride;
-				}
-			}
-			OS.g_object_unref(gicon_info);
-		}
-		OS.g_object_unref(gicon);
-	}
 	return data;
 }
 
@@ -258,19 +259,18 @@ static String gio_getMimeType(String extension) {
 	return mimeType;
 }
 
-static Program gio_getProgram(Display display, String mimeType) {
+static Program gio_getProgram(String mimeType) {
 	Program program = null;
 	byte[] mimeTypeBuffer = Converter.wcsToMbcs (mimeType, true);
 	long application = OS.g_app_info_get_default_for_type (mimeTypeBuffer, false);
 	if (application != 0) {
-		program = gio_getProgram(display, application);
+		program = gio_getProgram(application);
 	}
 	return program;
 }
 
-static Program gio_getProgram (Display display, long application) {
+static Program gio_getProgram (long application) {
 	Program program = new Program();
-	program.display = display;
 	int length;
 	byte[] buffer;
 	long applicationName = OS.g_app_info_get_name (application);
@@ -304,16 +304,18 @@ static Program gio_getProgram (Display display, long application) {
 			}
 			OS.g_free(icon_name);
 		}
-		OS.g_object_unref(icon);
 	}
 	return program.command != null ? program : null;
 }
 
-/*
- *  API: When support for multiple displays is added, this method will
- *       become public and the original method above can be deprecated.
+/**
+ * Answers all available programs in the operating system.  Note
+ * that a <code>Display</code> must already exist to guarantee
+ * that this method returns an appropriate result.
+ *
+ * @return an array of programs
  */
-static Program[] getPrograms(Display display) {
+public static Program[] getPrograms() {
 	long applicationList = OS.g_app_info_get_all ();
 	long list = applicationList;
 	Program program;
@@ -323,9 +325,10 @@ static Program[] getPrograms(Display display) {
 		if (application != 0) {
 			//TODO: Should the list be filtered or not?
 //			if (OS.g_app_info_should_show(application)) {
-				program = gio_getProgram(display, application);
+				program = gio_getProgram(application);
 				if (program != null) programs.add(program);
 //			}
+				OS.g_object_unref(application);
 		}
 		list = OS.g_list_next(list);
 	}
@@ -438,7 +441,7 @@ public static String[] getExtensions() {
  * </ul>
  */
 public static boolean launch(String fileName) {
-	return launch(Display.getCurrent(), fileName, null);
+	return launch(fileName, null);
 }
 
 /**
@@ -461,14 +464,6 @@ public static boolean launch(String fileName) {
  * @since 3.6
  */
 public static boolean launch (String fileName, String workingDir) {
-	return launch(Display.getCurrent(), fileName, workingDir);
-}
-
-/*
- *  API: When support for multiple displays is added, this method will
- *       become public and the original method above can be deprecated.
- */
-static boolean launch (Display display, String fileName, String workingDir) {
 	if (fileName == null) SWT.error (SWT.ERROR_NULL_ARGUMENT);
 	if (workingDir != null && isExecutable(fileName)) {
 		try {
@@ -482,14 +477,14 @@ static boolean launch (Display display, String fileName, String workingDir) {
 	int index = fileName.lastIndexOf ('.');
 	if (index != -1) {
 		String extension = fileName.substring (index);
-		Program program = Program.findProgram (display, extension);
+		Program program = Program.findProgram (extension);
 		if (program != null && program.execute (fileName)) return true;
 	}
 	String lowercaseName = fileName.toLowerCase ();
 	if (lowercaseName.startsWith (PREFIX_HTTP) || lowercaseName.startsWith (PREFIX_HTTPS)) {
-		Program program = Program.findProgram (display, ".html"); //$NON-NLS-1$
+		Program program = Program.findProgram (".html"); //$NON-NLS-1$
 		if (program == null) {
-			program = Program.findProgram (display, ".htm"); //$NON-NLS-1$
+			program = Program.findProgram (".htm"); //$NON-NLS-1$
 		}
 		if (program != null && program.execute (fileName)) return true;
 	}
@@ -517,7 +512,7 @@ public boolean equals(Object other) {
 	if (this == other) return true;
 	if (!(other instanceof Program)) return false;
 	Program program = (Program)other;
-	return display == program.display && name.equals(program.name) && command.equals(program.command)
+	return name.equals(program.name) && command.equals(program.command)
 			&& gioExpectUri == program.gioExpectUri;
 }
 
