@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others. All rights reserved.
+ * Copyright (c) 2000, 2021 IBM Corporation and others. All rights reserved.
  * The contents of this file are made available under the terms
  * of the GNU Lesser General Public License (LGPL) Version 2.1 that
  * accompanies this distribution (lgpl-v21.txt).  The LGPL is also
@@ -48,7 +48,7 @@ public class WebKitGTK extends C {
 			System.out.println("SWT_LIB  WebKit2   WebKitGTK:"+ webkit_get_major_version()+"."+ webkit_get_minor_version() + "."
 					+ webkit_get_micro_version() + "  (WebKitGTK >=2.5 is WebKit2) " + swtWebkitGlueCodeVersion + swtWebkitGlueCodeVersionInfo);
 		}
-	};
+	}
 
 	/** Constants */
 	public static final int kJSTypeUndefined = 0;
@@ -87,6 +87,8 @@ public class WebKitGTK extends C {
 
 	public static final int WEBKIT_WEBSITE_DATA_COOKIES = 1 << 8;
 
+	public static final int WEBKIT_USER_SCRIPT_INJECT_AT_DOCUMENT_START = 0;
+	public static final int WEBKIT_USER_CONTENT_INJECT_TOP_FRAME = 1;
 
 	/** Signals */
 
@@ -114,9 +116,6 @@ public class WebKitGTK extends C {
 	public static final byte[] failed = ascii ("failed"); // $NON-NLS-1$
 	public static final byte[] finished = ascii ("finished"); // $NON-NLS-1$
 
-	// Webkit2 extension
-	public static final byte[] initialize_web_extensions = ascii ("initialize-web-extensions");
-
 	// Status text signals
 	public static final byte[] mouse_target_changed = ascii ("mouse-target-changed"); // $NON-NLS-1$
 
@@ -179,9 +178,6 @@ public static final native long JSObjectGetProperty(long ctx, long object, long
 /** @method flags=dynamic */
 public static final native long JSObjectGetPropertyAtIndex(long ctx, long object, int propertyIndex, long [] exception);
 
-/** @method flags=dynamic */
-public static final native long JSObjectMakeArray(long ctx, long argumentCount, long [] arguments, long [] exception);
-
 /** @method flags=dynamic */
 public static final native long JSStringCreateWithUTF8CString(byte[] string);
 
@@ -202,18 +198,6 @@ public static final native void webkit_javascript_result_unref(long js_result);
 /** @method flags=dynamic */
 public static final native int JSValueGetType(long ctx, long value);
 
-/** @method flags=dynamic */
-public static final native long JSValueMakeBoolean(long ctx, int bool);
-
-/** @method flags=dynamic */
-public static final native long JSValueMakeNumber(long ctx, double number);
-
-/** @method flags=dynamic */
-public static final native long JSValueMakeString(long ctx, long string);
-
-/** @method flags=dynamic */
-public static final native long JSValueMakeUndefined(long ctx);
-
 /** @method flags=dynamic */
 public static final native double JSValueToNumber(long ctx, long value, long [] exception);
 
@@ -257,7 +241,7 @@ public static final native boolean webkit_authentication_request_is_retry(long r
 public static final native void webkit_cookie_manager_add_cookie(long cookie_manager, long cookie, long cancellable, long cb, long user_data);
 
 /** @method flags=dynamic */
-public static final native boolean webkit_cookie_manager_add_cookie_finish(long cookie_manager, long result, long error []);
+public static final native boolean webkit_cookie_manager_add_cookie_finish(long cookie_manager, long result, long[] error );
 
 /**
  * @method flags=dynamic
@@ -265,7 +249,7 @@ public static final native boolean webkit_cookie_manager_add_cookie_finish(long
 public static final native void webkit_cookie_manager_get_cookies(long cookie_manager, byte [] uri, long cancellable, long cb, long user_data);
 
 /** @method flags=dynamic */
-public static final native long webkit_cookie_manager_get_cookies_finish(long cookie_manager, long result, long error []);
+public static final native long webkit_cookie_manager_get_cookies_finish(long cookie_manager, long result, long[] error );
 
 /** @method flags=dynamic */
 public static final native void webkit_credential_free(long credential);
@@ -376,9 +360,15 @@ public static final native long webkit_web_context_get_cookie_manager(long conte
 /** @method flags=dynamic */
 public static final native long webkit_web_context_get_website_data_manager(long context);
 
+/** @method flags=dynamic */
+public static final native long webkit_web_context_get_security_manager(long context);
+
 /** @method flags=dynamic */
 public static final native void webkit_web_context_set_tls_errors_policy(long context, int policy);
 
+/** @method flags=dynamic */
+public static final native void webkit_web_context_register_uri_scheme(long context, byte[] scheme, long callback, long user_data, long user_data_destroy_func);
+
 /** @method flags=dynamic */
 public static final native int webkit_web_view_can_go_back(long web_view);
 
@@ -403,6 +393,9 @@ public static final native long webkit_web_view_get_page_id(long web_view);
 /** @method flags=dynamic */
 public static final native long webkit_web_view_get_settings(long web_view);
 
+/** @method flags=dynamic */
+public static final native long webkit_web_view_get_user_content_manager(long web_view);
+
 /** @method flags=dynamic */
 public static final native long webkit_web_view_get_title(long web_view);
 
@@ -441,14 +434,8 @@ public static final native void webkit_web_view_load_uri(long web_view, byte[] u
 
 /** @method flags=dynamic */
 public static final native long webkit_web_view_new();
-
-
-/** @method flags=dynamic */ // @param context cast=(WebKitWebContext*)  @param directory cast=(const gchar *)
-public static final native void webkit_web_context_set_web_extensions_directory(long context, byte[] directory);
-
 /** @method flags=dynamic */
-public static final native void webkit_web_context_set_web_extensions_initialization_user_data(long /* int */ context, long /* int */ user_data);
-
+public static final native long webkit_web_view_new_with_related_view(long web_view);
 
 /**
  * @method flags=dynamic
@@ -476,7 +463,7 @@ public static final native void webkit_web_view_run_javascript(long web_view, by
 public static final native void webkit_web_resource_get_data(long webKitWebResource, long gCancellable, long GAsyncReadyCallback, long user_data);
 
 /** @method flags=dynamic */
-public static final native long webkit_web_resource_get_data_finish(long WebKitWebResource, long GAsyncResult, long [] gsize, long GError[]);
+public static final native long webkit_web_resource_get_data_finish(long WebKitWebResource, long GAsyncResult, long [] gsize, long[] GError);
 
 
 /**
@@ -510,6 +497,36 @@ public static final native long webkit_uri_request_get_uri(long request);
 /** @method flags=dynamic */
 public static final native long webkit_uri_response_get_mime_type(long responce);
 
+/**
+ * @method flags=dynamic
+ * @param content_type flags=no_out
+ */
+public static final native void webkit_uri_scheme_request_finish(long request, long stream, long stream_length, byte[] content_type);
+
+/** @method flags=dynamic */
+public static final native long webkit_uri_scheme_request_get_uri (long request);
+
+/** @method flags=dynamic */
+public static final native long webkit_uri_scheme_request_get_web_view(long request);
+
+/** @method flags=dynamic */
+public static final native long webkit_user_content_manager_add_script(long manager, long script);
+
+/** @method flags=dynamic */
+public static final native void webkit_user_content_manager_remove_all_scripts(long manager);
+
+/** @method flags=dynamic */
+public static final native void webkit_security_manager_register_uri_scheme_as_secure(long security_manager, byte[] scheme);
+
+/**
+ * @method flags=dynamic
+ * @param source flags=no_out
+ */
+public static final native long webkit_user_script_new (byte[] source, int injected_frames, int injection_time, long allow_list, long block_list);
+
+/** @method flags=dynamic */
+public static final native void webkit_user_script_unref (long user_script);
+
 /* --------------------- start SWT natives --------------------- */
 public static final native int GdkRectangle_sizeof();
 
