@@ -97,6 +97,12 @@ public Region(Device device) {
 Region(Device device, long handle) {
 	super(device);
 	this.handle = handle;
+	/*
+	 * When created this way, Font doesn't own its .handle, and
+	 * for this reason it can't be disposed. Tell leak detector
+	 * to just ignore it.
+	 */
+	this.ignoreNonDisposed();
 }
 
 /**
@@ -368,10 +374,8 @@ NSAffineTransform transform;
 void convertRgn(NSAffineTransform transform) {
 	long newRgn = OS.NewRgn();
 	Callback callback = new Callback(this, "convertRgn", 4);
-	long proc = callback.getAddress();
-	if (proc == 0) SWT.error(SWT.ERROR_NO_MORE_CALLBACKS);
 	this.transform = transform;
-	OS.QDRegionToRects(handle, OS.kQDParseRegionFromTopLeft, proc, newRgn);
+	OS.QDRegionToRects(handle, OS.kQDParseRegionFromTopLeft, callback.getAddress(), newRgn);
 	this.transform = null;
 	callback.dispose();
 	OS.CopyRgn(newRgn, handle);
@@ -469,7 +473,6 @@ public Rectangle getBounds() {
 
 NSBezierPath getPath() {
 	Callback callback = new Callback(this, "regionToRects", 4);
-	if (callback.getAddress() == 0) SWT.error(SWT.ERROR_NO_MORE_CALLBACKS);
 	NSBezierPath path = NSBezierPath.bezierPath();
 	path.retain();
 	OS.QDRegionToRects(handle, OS.kQDParseRegionFromTopLeft, callback.getAddress(), path.id);
