@@ -236,19 +236,19 @@ void computeRuns() {
 			font.addTraits(attrStr, range);
 		}
 		Color foreground = style.foreground;
-		if (foreground != null) {
+		if (foreground != null && !foreground.isDisposed()) {
 			NSColor color = NSColor.colorWithDeviceRed(foreground.handle[0], foreground.handle[1], foreground.handle[2], 1);
 			attrStr.addAttribute(OS.NSForegroundColorAttributeName, color, range);
 		}
 		Color background = style.background;
-		if (background != null) {
+		if (background != null && !background.isDisposed()) {
 			NSColor color = NSColor.colorWithDeviceRed(background.handle[0], background.handle[1], background.handle[2], 1);
 			attrStr.addAttribute(OS.NSBackgroundColorAttributeName, color, range);
 		}
 		if (style.strikeout) {
 			attrStr.addAttribute(OS.NSStrikethroughStyleAttributeName, NSNumber.numberWithInt(OS.NSUnderlineStyleSingle), range);
 			Color strikeColor = style.strikeoutColor;
-			if (strikeColor != null) {
+			if (strikeColor != null && !strikeColor.isDisposed()) {
 				NSColor color = NSColor.colorWithDeviceRed(strikeColor.handle[0], strikeColor.handle[1], strikeColor.handle[2], 1);
 				attrStr.addAttribute(OS.NSStrikethroughColorAttributeName, color, range);
 			}
@@ -277,7 +277,7 @@ void computeRuns() {
 			if (underlineStyle != 0) {
 				attrStr.addAttribute(OS.NSUnderlineStyleAttributeName, NSNumber.numberWithInt(underlineStyle), range);
 				Color underlineColor = style.underlineColor;
-				if (underlineColor != null) {
+				if (underlineColor != null && !underlineColor.isDisposed()) {
 					NSColor color = NSColor.colorWithDeviceRed(underlineColor.handle[0], underlineColor.handle[1], underlineColor.handle[2], 1);
 					attrStr.addAttribute(OS.NSUnderlineColorAttributeName, color, range);
 				}
@@ -1624,7 +1624,6 @@ void initClasses () {
 
 	textLayoutCallback2 = new Callback(getClass(), "textLayoutProc", 2);
 	long proc2 = textLayoutCallback2.getAddress();
-	if (proc2 == 0) SWT.error(SWT.ERROR_NO_MORE_CALLBACKS);
 	long cellBaselineOffsetProc = OS.CALLBACK_cellBaselineOffset(proc2);
 	long cellSizeProc = OS.CALLBACK_NSTextAttachmentCell_cellSize(proc2);
 
@@ -1923,7 +1922,7 @@ public void setOrientation(int orientation) {
  * <p>
  * When segments characters are set, the segments are the offsets where
  * the characters are inserted in the text.
- * <p>
+ * </p>
  *
  * @param segments the text segments offset
  *
