@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2012 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,7 +14,10 @@
 package org.eclipse.swt.widgets;
 
 
+import java.util.*;
+
 import org.eclipse.swt.*;
+import org.eclipse.swt.internal.*;
 import org.eclipse.swt.internal.cocoa.*;
 
 /**
@@ -41,8 +44,10 @@ import org.eclipse.swt.internal.cocoa.*;
  * @noextend This class is not intended to be subclassed by clients.
  */
 public  class MessageBox extends Dialog {
+	Callback callback_completion_handler;
 	String message = "";
-	int returnCode;
+	int userResponse;
+	private Map<Integer, String> labels;
 
 /**
  * Constructs a new instance of this class given only its parent.
@@ -115,6 +120,12 @@ static int checkStyle (int style) {
 	return style;
 }
 
+private int getBits () {
+	int mask = (SWT.YES | SWT.NO | SWT.OK | SWT.CANCEL | SWT.ABORT | SWT.RETRY | SWT.IGNORE);
+	int bits = style & mask;
+	return bits;
+}
+
 /**
  * Returns the dialog's message, or an empty string if it does not have one.
  * The message is a description of the purpose for which the dialog was opened.
@@ -146,71 +157,78 @@ public int open () {
 	}
 	if (((style & SWT.ICON_INFORMATION) != 0) || ((style & SWT.ICON_WORKING) != 0) || ((style & SWT.ICON_QUESTION) != 0)) {
 		alertType = OS.NSInformationalAlertStyle;
-		NSImage icon = Display.getSystemImageForID(OS.kAlertNoteIcon);
-		alert.setIcon(icon);
-		icon.release();
+		if (OS.isBigSurOrLater()) {
+			alert.setIcon(NSImage.imageNamed(OS.NSImageNameInfo));
+		} else {
+			NSImage icon = Display.getSystemImageForID(OS.kAlertNoteIcon);
+			alert.setIcon(icon);
+			icon.release();
+		}
 	}
 	if ((style & SWT.ICON_WARNING) != 0) {
 		alertType = OS.NSWarningAlertStyle;
-		NSImage icon = Display.getSystemImageForID(OS.kAlertCautionIcon);
-		alert.setIcon(icon);
-		icon.release();
+		if (OS.isBigSurOrLater()) {
+			alert.setIcon(NSImage.imageNamed(OS.NSImageNameCaution));
+		} else {
+			NSImage icon = Display.getSystemImageForID(OS.kAlertCautionIcon);
+			alert.setIcon(icon);
+			icon.release();
+		}
 	}
 	alert.setAlertStyle(alertType);
 
-	int mask = (SWT.YES | SWT.NO | SWT.OK | SWT.CANCEL | SWT.ABORT | SWT.RETRY | SWT.IGNORE);
-	int bits = style & mask;
+	int bits = getBits();
 	NSString title;
 	switch (bits) {
 		case SWT.OK:
-			title = NSString.stringWith(SWT.getMessage("SWT_OK"));
+			title = getLabelForButton(SWT.OK, "SWT_OK");
 			alert.addButtonWithTitle(title);
 			break;
 		case SWT.CANCEL:
-			title = NSString.stringWith(SWT.getMessage("SWT_Cancel"));
+			title = getLabelForButton(SWT.CANCEL, "SWT_Cancel");
 			alert.addButtonWithTitle(title);
 			break;
 		case SWT.OK | SWT.CANCEL:
-			title = NSString.stringWith(SWT.getMessage("SWT_OK"));
+			title = getLabelForButton(SWT.OK, "SWT_OK");
 			alert.addButtonWithTitle(title);
-			title = NSString.stringWith(SWT.getMessage("SWT_Cancel"));
+			title = getLabelForButton( SWT.CANCEL, "SWT_Cancel");
 			alert.addButtonWithTitle(title);
 			break;
 		case SWT.YES:
-			title = NSString.stringWith(SWT.getMessage("SWT_Yes"));
+			title = getLabelForButton(SWT.YES, "SWT_Yes");
 			alert.addButtonWithTitle(title);
 			break;
 		case SWT.NO:
-			title = NSString.stringWith(SWT.getMessage("SWT_No"));
+			title = getLabelForButton(SWT.NO, "SWT_No");
 			alert.addButtonWithTitle(title);
 			break;
 		case SWT.YES | SWT.NO:
-			title = NSString.stringWith(SWT.getMessage("SWT_Yes"));
+			title = getLabelForButton(SWT.YES, "SWT_Yes");
 			alert.addButtonWithTitle(title);
-			title = NSString.stringWith(SWT.getMessage("SWT_No"));
+			title = getLabelForButton(SWT.NO, "SWT_No");
 			alert.addButtonWithTitle(title);
 //			no.setKeyEquivalent(NSString.stringWith("\033"));
 			break;
 		case SWT.YES | SWT.NO | SWT.CANCEL:
-			title = NSString.stringWith(SWT.getMessage("SWT_Yes"));
+			title = getLabelForButton(SWT.YES, "SWT_Yes");
 			alert.addButtonWithTitle(title);
-			title = NSString.stringWith(SWT.getMessage("SWT_Cancel"));
+			title = getLabelForButton( SWT.CANCEL, "SWT_Cancel");
 			alert.addButtonWithTitle(title);
-			title = NSString.stringWith(SWT.getMessage("SWT_No"));
+			title = getLabelForButton(SWT.NO, "SWT_No");
 			alert.addButtonWithTitle(title);
 			break;
 		case SWT.RETRY | SWT.CANCEL:
-			title = NSString.stringWith(SWT.getMessage("SWT_Retry"));
+			title = getLabelForButton( SWT.RETRY, "SWT_Retry");
 			alert.addButtonWithTitle(title);
-			title = NSString.stringWith(SWT.getMessage("SWT_Cancel"));
+			title = getLabelForButton( SWT.CANCEL, "SWT_Cancel");
 			alert.addButtonWithTitle(title);
 			break;
 		case SWT.ABORT | SWT.RETRY | SWT.IGNORE:
-			title = NSString.stringWith(SWT.getMessage("SWT_Abort"));
+			title = getLabelForButton( SWT.ABORT, "SWT_Abort");
 			alert.addButtonWithTitle(title);
-			title = NSString.stringWith(SWT.getMessage("SWT_Ignore"));
+			title = getLabelForButton( SWT.IGNORE, "SWT_Ignore");
 			alert.addButtonWithTitle(title);
-			title = NSString.stringWith(SWT.getMessage("SWT_Retry"));
+			title = getLabelForButton( SWT.RETRY, "SWT_Retry");
 			alert.addButtonWithTitle(title);
 			break;
 	}
@@ -219,7 +237,7 @@ public int open () {
 	panel.setTitle(title);
 	NSString message = NSString.stringWith(this.message != null ? this.message : "");
 	alert.setMessageText(message);
-	int response = 0;
+
 	long jniRef = 0;
 	SWTPanelDelegate delegate = null;
 	Display display = parent != null ? parent.getDisplay() : Display.getCurrent();
@@ -228,26 +246,46 @@ public int open () {
 		jniRef = OS.NewGlobalRef(this);
 		if (jniRef == 0) error(SWT.ERROR_NO_HANDLES);
 		OS.object_setInstanceVariable(delegate.id, Display.SWT_OBJECT, jniRef);
-		alert.beginSheetModalForWindow(parent.view.window (), delegate, OS.sel_panelDidEnd_returnCode_contextInfo_, 0);
 		display.setModalDialog(this, panel);
+		callback_completion_handler = new Callback(this, "_completionHandler", 1);
+		long handler = callback_completion_handler.getAddress();
+		OS.beginSheetModalForWindow(alert, parent.window, handler);
+
 		if ((style & SWT.APPLICATION_MODAL) != 0) {
-			response = (int)alert.runModal();
+			alert.runModal();
 		} else {
-			this.returnCode = 0;
 			NSWindow window = alert.window();
 			while (window.isVisible()) {
 				if (!display.readAndDispatch()) display.sleep();
 			}
-			response = this.returnCode;
 		}
 	} else {
 		display.setModalDialog(this, panel);
-		response = (int)alert.runModal();
+		int response = (int)alert.runModal();
+		userResponse = handleResponse(bits, response);
 	}
 	display.setModalDialog(null);
 	if (delegate != null) delegate.release();
 	if (jniRef != 0) OS.DeleteGlobalRef(jniRef);
 	alert.release();
+	releaseHandler();
+	return userResponse;
+}
+
+private NSString getLabelForButton(int buttonId, String messageId) {
+	if (labels !=null && labels.containsKey(buttonId) && labels.get(buttonId) != null) {
+		return NSString.stringWith(labels.get(buttonId));
+	}
+	return NSString.stringWith(SWT.getMessage(messageId));
+}
+
+long _completionHandler (long result) {
+	NSApplication.sharedApplication().stopModal();
+	userResponse = handleResponse(getBits(), (int)result);
+	return result;
+}
+
+int handleResponse (int bits, int response) {
 	switch (bits) {
 		case SWT.OK:
 			switch (response) {
@@ -321,10 +359,11 @@ public int open () {
 	return SWT.CANCEL;
 }
 
-void panelDidEnd_returnCode_contextInfo(long id, long sel, long alert, long returnCode, long contextInfo) {
-	this.returnCode = (int)returnCode;
-	NSApplication application = NSApplication.sharedApplication();
-	application.endSheet(new NSAlert(alert).window(), returnCode);
+void releaseHandler () {
+	if (callback_completion_handler != null) {
+		callback_completion_handler.dispose();
+		callback_completion_handler = null;
+	}
 }
 
 /**
@@ -343,4 +382,27 @@ public void setMessage (String string) {
 	message = string;
 }
 
+/**
+ * Set custom text for <code>MessageDialog</code>'s buttons:
+ *
+ * @param labels a <code>Map</code> where a valid 'key' is from below listed
+ *               styles:<ul>
+ * <li>SWT#OK</li>
+ * <li>SWT#CANCEL</li>
+ * <li>SWT#YES</li>
+ * <li>SWT#NO</li>
+ * <li>SWT#ABORT</li>
+ * <li>SWT#RETRY</li>
+ * <li>SWT#IGNORE</li>
+ * </ul>
+ * @exception IllegalArgumentException <ul>
+ *    <li>ERROR_NULL_ARGUMENT - if labels is null</li>
+ * </ul>
+ * @since 3.121
+ */
+public void setButtonLabels(Map<Integer, String> labels) {
+	if (labels == null) error (SWT.ERROR_NULL_ARGUMENT);
+	this.labels = labels;
+}
+
 }
