@@ -372,7 +372,10 @@ void drawInteriorWithFrame_inView(long id, long sel, NSRect cellFrame, long view
 @Override
 Cursor findCursor () {
 	Cursor cursor = super.findCursor ();
-	return (cursor != null || (style & SWT.READ_ONLY) != 0) ? cursor : display.getSystemCursor (SWT.CURSOR_IBEAM);
+	if (cursor == null && (style & SWT.READ_ONLY) == 0 && OS.VERSION < OS.VERSION(10, 14, 0)) {
+		cursor = display.getSystemCursor (SWT.CURSOR_IBEAM);
+	}
+	return cursor;
 }
 
 @Override
