@@ -21,13 +21,13 @@ import org.eclipse.swt.internal.cocoa.*;
 
 /**
  * Instances of this class represent a column in a table widget.
- * <p><dl>
+ * <dl>
  * <dt><b>Styles:</b></dt>
  * <dd>LEFT, RIGHT, CENTER</dd>
  * <dt><b>Events:</b></dt>
  * <dd> Move, Resize, Selection</dd>
  * </dl>
- * </p><p>
+ * <p>
  * Note: Only one of the styles LEFT, RIGHT and CENTER may be specified.
  * </p><p>
  * IMPORTANT: This class is <em>not</em> intended to be subclassed.
@@ -207,7 +207,7 @@ void destroyWidget () {
 }
 
 @Override
-void drawInteriorWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cellRect, long /*int*/ view) {
+void drawInteriorWithFrame_inView (long id, long sel, NSRect cellRect, long view) {
 	/*
 	 * Feature in Cocoa.  When the last column in a table does not reach the
 	 * rightmost edge of the table view, the cell that draws the rightmost-
@@ -252,7 +252,7 @@ void drawInteriorWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cel
 	NSTableHeaderCell headerCell = nsColumn.headerCell ();
 	if (displayText != null) {
 		Font font = Font.cocoa_new(display, headerCell.font ());
-		attrString = parent.createString(displayText, font, parent.headerForeground, SWT.LEFT, false, (parent.state & DISABLED) == 0, false);
+		attrString = parent.createString(displayText, font, parent.getHeaderForegroundColor().handle, SWT.LEFT, false, (parent.state & DISABLED) == 0, false);
 		stringSize = attrString.size ();
 		contentWidth += Math.ceil (stringSize.width);
 		if (image != null) contentWidth += MARGIN; /* space between image and text */
@@ -261,7 +261,7 @@ void drawInteriorWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cel
 	if (parent.headerBackground != null) {
 		// fill header background
 		context.saveGraphicsState();
-		double /*float*/ [] colorRGB = parent.headerBackground;
+		double [] colorRGB = parent.headerBackground;
 		NSColor color1 = NSColor.colorWithDeviceRed(colorRGB[0], colorRGB[1], colorRGB[2], 1f);
 		color1.setFill();
 		/*
@@ -306,7 +306,7 @@ void drawInteriorWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cel
 			NSRect sortIndicatorRect = headerCell.sortIndicatorRectForBounds(cellRect);
 			context.saveGraphicsState();
 			if (parent.headerForeground != null) {
-				double /*float*/ [] colorRGB = parent.headerForeground;
+				double [] colorRGB = parent.headerForeground;
 				NSColor color = NSColor.colorWithDeviceRed(colorRGB[0], colorRGB[1], colorRGB[2], 0.9f);
 				color.setStroke();
 			}
@@ -368,9 +368,9 @@ void drawInteriorWithFrame_inView (long /*int*/ id, long /*int*/ sel, NSRect cel
 		if (isFlipped) {
 			context.saveGraphicsState ();
 			NSAffineTransform transform = NSAffineTransform.transform ();
-		 	transform.scaleXBy (1, -1);
-		 	transform.translateXBy (0, -(destRect.height + 2 * destRect.y));
-		 	transform.concat ();
+			transform.scaleXBy (1, -1);
+			transform.translateXBy (0, -(destRect.height + 2 * destRect.y));
+			transform.concat ();
 		}
 		NSRect sourceRect = new NSRect ();
 		sourceRect.width = destRect.width;
@@ -741,7 +741,7 @@ public void setText (String string) {
  * </p>
  * <p>
  * NOTE: This operation is a hint and behavior is platform specific, on Windows
- * for CJK-style mnemonics of the form " (&C)" at the end of the tooltip text
+ * for CJK-style mnemonics of the form " (&amp;C)" at the end of the tooltip text
  * are not shown in tooltip.
  * </p>
  *
