@@ -105,7 +105,7 @@ public abstract class Widget {
 	static final int DEFAULT_HEIGHT	= 64;
 
 Widget () {
-	/* Do nothing */
+	notifyCreationTracker();
 }
 
 /**
@@ -143,6 +143,7 @@ public Widget (Widget parent, int style) {
 	this.style = style;
 	display = parent.display;
 	reskinWidget ();
+	notifyCreationTracker();
 }
 
 long accessibleHandle() {
@@ -1348,24 +1349,35 @@ void register () {
 }
 
 void release (boolean destroy) {
-	if ((state & DISPOSE_SENT) == 0) {
-		state |= DISPOSE_SENT;
-		sendEvent (SWT.Dispose);
-	}
-	if ((state & DISPOSED) == 0) {
-		releaseChildren (destroy);
-	}
-	if ((state & RELEASED) == 0) {
-		state |= RELEASED;
-		if (destroy) {
-			releaseParent ();
-			releaseWidget ();
-			destroyWidget ();
-		} else {
-			releaseWidget ();
-			releaseHandle ();
+	try (ExceptionStash exceptions = new ExceptionStash ()) {
+		if ((state & DISPOSE_SENT) == 0) {
+			state |= DISPOSE_SENT;
+			try {
+				sendEvent (SWT.Dispose);
+			} catch (Error | RuntimeException ex) {
+				exceptions.stash (ex);
+			}
+		}
+		if ((state & DISPOSED) == 0) {
+			try {
+				releaseChildren (destroy);
+			} catch (Error | RuntimeException ex) {
+				exceptions.stash (ex);
+			}
+		}
+		if ((state & RELEASED) == 0) {
+			state |= RELEASED;
+			if (destroy) {
+				releaseParent ();
+				releaseWidget ();
+				destroyWidget ();
+			} else {
+				releaseWidget ();
+				releaseHandle ();
+			}
 		}
 	}
+	notifyDisposalTracker();
 }
 
 void releaseChildren (boolean destroy) {
@@ -1778,6 +1790,138 @@ boolean setInputState (Event event, NSEvent nsEvent, int type) {
 	return true;
 }
 
+private int getKeyboardType(NSEvent nsEvent) {
+	long cgEvent = nsEvent.CGEvent();
+	return (int)OS.CGEventGetIntegerValueField(cgEvent, OS.kCGKeyboardEventKeyboardType);
+}
+
+private int calculateKeycode(Event event, NSEvent nsEvent) {
+	long keyLayout = Display.getCurrentKeyLayout();
+	if (keyLayout == 0) {
+		// KCHR keyboard layouts are no longer supported, so fall back to the basic but flawed
+		// method of determining which key was pressed.
+		NSString unmodifiedChars = nsEvent.charactersIgnoringModifiers ().lowercaseString();
+		if (unmodifiedChars.length() == 0) return 0;
+		return unmodifiedChars.characterAtIndex(0);
+	}
+
+	short nsKeyCode = nsEvent.keyCode ();
+	short keyAction = event.type == SWT.KeyDown ? OS.kUCKeyActionDown : OS.kUCKeyActionUp;
+	int keyboardType = getKeyboardType(nsEvent);
+	int maxStringLength = 256;
+	char [] unicodeString = new char [maxStringLength];
+	long [] actualStringLength = new long [1];
+	int [] deadKeyState = new int[1];
+
+	// Note that bit shift >> 8 in modifiers is needed according to docs
+	// of UCKeyTranslate().
+	final int [] modifierTests = new int[] {
+		// Many non-latin layouts have a latin plane on Cmd key in order
+		// to handle keyboard shortcuts. Furthermore, layouts such as
+		// 'Dvorak-QWERTY⌘' have different latin planes without Cmd (for
+		// typing) and with Cmd (for invoking shortcuts). In both cases,
+		// that's exactly what we want for 'Event.keyCode'.
+		OS.cmdKey >> 8,
+		// Fallback just in case. It's unknown if it's actually helpful
+		// in any layouts.
+		0,
+	};
+
+	for (int modifiers : modifierTests) {
+		OS.UCKeyTranslate (keyLayout, nsKeyCode, keyAction, modifiers, keyboardType, 0, deadKeyState, maxStringLength, actualStringLength, unicodeString);
+		if (actualStringLength[0] < 1) {
+			// part of a multi-key key
+			continue;
+		}
+
+		if (unicodeString[0] < 128) {
+			// Found something latin, use that
+			return unicodeString[0];
+		}
+	}
+
+	// If nothing worked, return values from the last tested modifiers
+	if (actualStringLength[0] < 1) return 0;
+	return unicodeString[0];
+}
+
+/**
+ * For every key press, macOS reports these pieces of information:
+ * <ul>
+ *  <li>-[NSEvent keyCode] contains the physical key id, it doesn't
+ *   change across keyboard layouts.</li>
+ *  <li>-[NSEvent modifierFlags] is the modifiers (Cmd, Shift etc)</li>
+ *  <li>-[NSEvent characters] is the translated character with
+ *   keyboard layout, keyCode, modifiers taken into account</li>
+ *  <li>-[NSEvent charactersIgnoringModifiers] is similar to the
+ *   previous one, but ignores modifiers other than Shift</li>
+ * </ul>
+ * Let's see some examples: (chars=-[NSEvent characters],
+ * charsNoMods=-[NSEvent charactersIgnoringModifiers])<br>
+ * <table>
+ *  <tr><th>Layout    </th><th>US key label</th><th>keyCode</th><th>chars</th><th>charsNoMods</th></tr>
+ *  <tr><td>U.S.      </td><td>2           </td><td>0x13   </td><td>2   </td><td>2        </td></tr>
+ *  <tr><td>U.S.      </td><td>Cmd+2       </td><td>0x13   </td><td>2   </td><td>2        </td></tr>
+ *  <tr><td>U.S.      </td><td>Shift+2     </td><td>0x13   </td><td>@   </td><td>@        </td></tr>
+ *  <tr><td>U.S.      </td><td>V           </td><td>0x09   </td><td>v   </td><td>v        </td></tr>
+ *  <tr><td>U.S.      </td><td>Opt+V       </td><td>0x09   </td><td>√   </td><td>v        </td></tr>
+ *  <tr><td>U.S.      </td><td>Cmd+V       </td><td>0x09   </td><td>v   </td><td>v        </td></tr>
+ *  <tr><td>U.S.      </td><td>Ctrl+V      </td><td>0x09   </td><td>0x16</td><td>v        </td></tr>
+ *  <tr><td>U.S.      </td><td>Shift+V     </td><td>0x09   </td><td>V   </td><td>V        </td></tr>
+ *  <tr><td>U.S.      </td><td>Opt+Cmd+O   </td><td>0x1F   </td><td>ø   </td><td>o        </td></tr>
+ *  <tr><td>ABC-AZERTY</td><td>2           </td><td>0x13   </td><td>é   </td><td>é        </td></tr>
+ *  <tr><td>ABC-AZERTY</td><td>Cmd+2       </td><td>0x13   </td><td>é   </td><td>é        </td></tr>
+ *  <tr><td>ABC-AZERTY</td><td>Shift+2     </td><td>0x13   </td><td>2   </td><td>2        </td></tr>
+ *  <tr><td>Bulgarian </td><td>V           </td><td>0x09   </td><td>э   </td><td>э        </td></tr>
+ *  <tr><td>Bulgarian </td><td>Opt+V       </td><td>0x09   </td><td>v   </td><td>э        </td></tr>
+ *  <tr><td>Bulgarian </td><td>Cmd+V       </td><td>0x09   </td><td>v   </td><td>э        </td></tr>
+ *  <tr><td>Bulgarian </td><td>Ctrl+V      </td><td>0x09   </td><td>0x16</td><td>э        </td></tr>
+ *  <tr><td>Bulgarian </td><td>Shift+V     </td><td>0x09   </td><td>Э   </td><td>Э        </td></tr>
+ *  <tr><td>Bulgarian </td><td>Opt+Cmd+O   </td><td>0x1F   </td><td>o   </td><td>д        </td></tr>
+ *  <tr><td>Russian   </td><td>V           </td><td>0x09   </td><td>м   </td><td>м        </td></tr>
+ *  <tr><td>Russian   </td><td>Opt+V       </td><td>0x09   </td><td>µ   </td><td>м        </td></tr>
+ *  <tr><td>Russian   </td><td>Cmd+V       </td><td>0x09   </td><td>v   </td><td>м        </td></tr>
+ *  <tr><td>Russian   </td><td>Ctrl+V      </td><td>0x09   </td><td>0x16</td><td>м        </td></tr>
+ *  <tr><td>Russian   </td><td>Shift+V     </td><td>0x09   </td><td>М   </td><td>М        </td></tr>
+ * </table><br>
+ *
+ * Here, problems can be seen:
+ * <ul>
+ *  <li>In non-latin layouts such as Bulgarian, with Cmd and/or Opt
+ *   mods, -[NSEvent characters] contains a character good for
+ *   keyboard shortcuts, but without modifiers, it's not given
+ *   anywhere</li>
+ *  <li>In some non-latin layouts, Opt modifier results in good value
+ *   in -[NSEvent characters] (see Bulgarian), but in others, it
+ *   doesn't (see Russian)</li>
+ *  <li>In a lot of layouts, Shift+letter gives capital letter</li>
+ *  <li>In U.S. layout, Shift+2 doesn't give 2 anywhere</li>
+ *  <li>On the contrary, in layouts such as ABC-AZERTY (used in French),
+ *   digits keys don't give digits anywhere unless Shift is pressed</li>
+ *  <li>For Opt+Cmd+O, the good character is present, but in
+ *   U.S. it's reported in -[NSEvent charactersIgnoringModifiers]
+ *   while in Bulgarian it's reported in -[NSEvent characters]</li>
+ * </ul>
+ *
+ * macOS documentation, such as in -[NSResponder performKeyEquivalent:],
+ * suggests to use -[NSEvent charactersIgnoringModifiers], but clealry
+ * this isn't going to work.
+ *
+ * What macOS does itself in -[NSMenu performKeyEquivalent:] is a lot
+ * of undocumented magic, where it also maps physical keys to other
+ * layouts such as
+ * <ul>
+ *  <li>TISCopyCurrentASCIICapableKeyboardLayoutInputSource - a
+ *   documented API that returns "most-recently-used ASCII-capable
+ *   keyboard"</li>
+ *  <li>TSMDefaultAsciiCapableKeyboardLayoutCopy - a non documented
+ *   API whose meaning is hinted in documentation for previous API,
+ *   "default ASCII-capable keyboard layout (chosen by Setup Assistant)"</li>
+ * </ul>
+ *
+ * For an example of how other software deals with all that mess, see
+ * TISInputSourceWrapper::InitKeyEvent() in Firefox.
+ */
 boolean setKeyState (Event event, int type, NSEvent nsEvent) {
 	boolean isNull = false;
 	int keyCode = nsEvent.keyCode ();
@@ -1805,37 +1949,7 @@ boolean setKeyState (Event event, int type, NSEvent nsEvent) {
 				if (chars != null && chars.length() > 0) event.character = (char)chars.characterAtIndex (0);
 			}
 			if (event.keyCode == 0) {
-				long uchrPtr = 0;
-				long currentKbd = OS.TISCopyCurrentKeyboardInputSource();
-				long uchrCFData = OS.TISGetInputSourceProperty(currentKbd, OS.kTISPropertyUnicodeKeyLayoutData());
-
-				if (uchrCFData != 0) {
-					uchrPtr = OS.CFDataGetBytePtr(uchrCFData);
-
-					if (uchrPtr != 0 && OS.CFDataGetLength(uchrCFData) > 0) {
-						long cgEvent = nsEvent.CGEvent();
-						long keyboardType = OS.CGEventGetIntegerValueField(cgEvent, OS.kCGKeyboardEventKeyboardType);
-
-						int maxStringLength = 256;
-						char [] output = new char [maxStringLength];
-						long [] actualStringLength = new long [1];
-						int [] deadKeyState = new int[1];
-						OS.UCKeyTranslate (uchrPtr, (short)keyCode, (short)(event.type == SWT.KeyDown ? OS.kUCKeyActionDown : OS.kUCKeyActionUp), 0, (int)keyboardType, 0, deadKeyState, maxStringLength, actualStringLength, output);
-						if (actualStringLength[0] < 1) {
-							// part of a multi-key key
-							event.keyCode = 0;
-						} else {
-							event.keyCode = output[0];
-						}
-					}
-				} else {
-					// KCHR keyboard layouts are no longer supported, so fall back to the basic but flawed
-					// method of determining which key was pressed.
-					NSString unmodifiedChars = nsEvent.charactersIgnoringModifiers ().lowercaseString();
-					if (unmodifiedChars.length() > 0) event.keyCode = (char)unmodifiedChars.characterAtIndex(0);
-				}
-
-				if (currentKbd != 0) OS.CFRelease(currentKbd);
+				event.keyCode = calculateKeycode(event, nsEvent);
 			}
 	}
 	if (event.keyCode == 0 && event.character == 0) {
@@ -2180,4 +2294,16 @@ boolean writeSelectionToPasteboard(long id, long sel, long pasteboard, long type
 	return false;
 }
 
+void notifyCreationTracker() {
+	if (WidgetSpy.isEnabled) {
+		WidgetSpy.getInstance().widgetCreated(this);
+	}
+}
+
+void notifyDisposalTracker() {
+	if (WidgetSpy.isEnabled) {
+		WidgetSpy.getInstance().widgetDisposed(this);
+	}
+}
+
 }
