@@ -1,17 +1,21 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * Copyright (c) 2000, 2016 IBM Corporation and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Lars Vogel <Lars.Vogel@vogella.com> - Bug 502576
  *******************************************************************************/
 package org.eclipse.swt.events;
 
 
-import org.eclipse.swt.internal.SWTEventListener;
+import org.eclipse.swt.internal.*;
 
 /**
  * Classes which implement this interface provide a method
@@ -28,6 +32,7 @@ import org.eclipse.swt.internal.SWTEventListener;
  *
  * @see HelpEvent
  */
+@FunctionalInterface
 public interface HelpListener extends SWTEventListener {
 
 /**
@@ -36,5 +41,5 @@ public interface HelpListener extends SWTEventListener {
  *
  * @param e an event containing information about the help
  */
-public void helpRequested(HelpEvent e);
+void helpRequested(HelpEvent e);
 }
