@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -115,10 +115,22 @@ void computeRuns () {
 	String segmentsText = getSegmentsText();
 	byte[] buffer = Converter.wcsToMbcs(segmentsText, false);
 	OS.pango_layout_set_text (layout, buffer, buffer.length);
-	if (stylesCount == 2 && styles[0].style == null && ascentInPoints == -1 && descentInPoints == -1 && segments == null) return;
-	long ptr = OS.pango_layout_get_text(layout);
 	attrList = OS.pango_attr_list_new();
 	selAttrList = OS.pango_attr_list_new();
+	// pango_attr_insert_hyphens_new function is available only on Pango 1.44.0+
+	// pango_version (used for version check) encodes the version in an integer via
+	// the following formula:
+	// MAJOR*10000+MINOR*100+MICRO
+	if ((1 * 10000 + 44 * 100 + 0) <= OS.pango_version()) {
+		long hyphenAttr = OS.pango_attr_insert_hyphens_new(false);
+		OS.pango_attr_list_insert(attrList, hyphenAttr);
+		OS.pango_attr_list_insert(selAttrList, OS.pango_attribute_copy(hyphenAttr));
+	}
+	if (stylesCount == 2 && styles[0].style == null && ascentInPoints == -1 && descentInPoints == -1 && segments == null) {
+		OS.pango_layout_set_attributes(layout, attrList);
+		return;
+	}
+	long ptr = OS.pango_layout_get_text(layout);
 	PangoAttribute attribute = new PangoAttribute();
 	char[] chars = null;
 	int segementsLength = segmentsText.length();
@@ -584,8 +596,6 @@ void drawInPixels(GC gc, int x, int y, int selectionStart, int selectionEnd, Col
 	Cairo.cairo_new_path(cairo);
 }
 
-// Bug 477950: In order to support GTK2 and GTK3 colors simultaneously, this method's parameters
-// were modified to accept SWT Color objects instead of GdkColor structs.
 void drawWithCairo(GC gc, int x, int y, int start, int end, boolean fullSelection, GdkRGBA fg, GdkRGBA bg) {
 	GCData data = gc.data;
 	long cairo = data.cairo;
@@ -743,17 +753,11 @@ public int getAscent () {
  * @see #getLineBounds(int)
  */
 public Rectangle getBounds() {
-	checkLayout();
-	Rectangle bounds = DPIUtil.autoScaleDown(getDevice(), getBoundsInPixels());
-	int lineCount = OS.pango_layout_get_line_count(layout);
-	int totalLineheight = getScaledVerticalIndent();
-	for (int i = 0; i < lineCount; i++) {
-		totalLineheight += this.getLineBounds(i).height + OS.PANGO_PIXELS(OS.pango_layout_get_spacing(layout));
-	}
-	bounds.height = totalLineheight;
-	return bounds;
+	int spacingInPixels = getSpacingInPixels();
+	return DPIUtil.autoScaleDown(getDevice(), getBoundsInPixels(spacingInPixels));
 }
-Rectangle getBoundsInPixels() {
+
+Rectangle getBoundsInPixels(int spacingInPixels) {
 	checkLayout();
 	computeRuns();
 	int[] w = new int[1], h = new int[1];
@@ -765,7 +769,7 @@ Rectangle getBoundsInPixels() {
 	if (ascentInPoints != -1 && descentInPoints != -1) {
 		height = Math.max (height, DPIUtil.autoScaleUp(getDevice(), ascentInPoints + descentInPoints));
 	}
-	height += OS.PANGO_PIXELS(OS.pango_layout_get_spacing(layout));
+	height += spacingInPixels;
 	return new Rectangle(0, 0, width, height + getScaledVerticalIndent());
 }
 
@@ -981,11 +985,18 @@ Rectangle getLineBoundsInPixels(int lineIndex) {
 	int lineCount = OS.pango_layout_get_line_count(layout);
 	if (!(0 <= lineIndex && lineIndex < lineCount)) SWT.error(SWT.ERROR_INVALID_RANGE);
 	long iter = OS.pango_layout_get_iter(layout);
+	for (int i = 0; i < lineIndex; i++) {
+		OS.pango_layout_iter_next_line(iter);
+	}
+	Rectangle lineBoundsInPixels = getLineBoundsInPixels(lineIndex, iter);
+	OS.pango_layout_iter_free(iter);
+	return lineBoundsInPixels;
+}
+
+private Rectangle getLineBoundsInPixels(int lineIndex, long iter) {
 	if (iter == 0) SWT.error(SWT.ERROR_NO_HANDLES);
-	for (int i = 0; i < lineIndex; i++) OS.pango_layout_iter_next_line(iter);
 	PangoRectangle rect = new PangoRectangle();
 	OS.pango_layout_iter_get_line_extents(iter, null, rect);
-	OS.pango_layout_iter_free(iter);
 	int x = OS.PANGO_PIXELS(rect.x);
 	int y = OS.PANGO_PIXELS(rect.y);
 	int width = OS.PANGO_PIXELS(rect.width);
@@ -1088,7 +1099,11 @@ public FontMetrics getLineMetrics (int lineIndex) {
 	heightInPoints = Math.max(this.ascentInPoints + this.descentInPoints, heightInPoints);
 	ascentInPoints = Math.max(this.ascentInPoints, ascentInPoints);
 	int descentInPoints = heightInPoints - ascentInPoints;
-	return FontMetrics.gtk_new(ascentInPoints, descentInPoints, 0);
+	FontMetrics fm = new FontMetrics();
+	fm.ascentInPoints = ascentInPoints;
+	fm.descentInPoints = descentInPoints;
+	fm.averageCharWidthInPoints = 0;
+	return fm;
 }
 
 /**
@@ -1941,7 +1956,7 @@ public void setVerticalIndent (int verticalIndent) {
  * <p>
  * When segments characters are set, the segments are the offsets where
  * the characters are inserted in the text.
- * <p>
+ * </p>
  *
  * @param segments the text segments offset
  *
