@@ -18,6 +18,8 @@ import org.eclipse.swt.*;
 import org.eclipse.swt.graphics.*;
 import org.eclipse.swt.internal.*;
 import org.eclipse.swt.internal.gtk.*;
+import org.eclipse.swt.internal.gtk3.*;
+import org.eclipse.swt.internal.gtk4.*;
 
 /**
  * Instances of this class allow the user to select a font
@@ -199,14 +201,7 @@ public FontData open () {
 	} else {
 		display.externalEventLoop = true;
 		display.sendPreExternalEventDispatchEvent();
-		response = GTK.gtk_dialog_run(handle);
-		/*
-		* This call to gdk_threads_leave() is a temporary work around
-		* to avoid deadlocks when gdk_threads_init() is called by native
-		* code outside of SWT (i.e AWT, etc). It ensures that the current
-		* thread leaves the GTK lock acquired by the function above.
-		*/
-		GDK.gdk_threads_leave();
+		response = GTK3.gtk_dialog_run(handle);
 		display.externalEventLoop = false;
 		display.sendPostExternalEventDispatchEvent();
 	}
@@ -235,9 +230,9 @@ public FontData open () {
 	display.removeIdleProc ();
 
 	if (GTK.GTK4) {
-		OS.g_object_unref(handle);
+		GTK4.gtk_window_destroy(handle);
 	} else {
-		GTK.gtk_widget_destroy(handle);
+		GTK3.gtk_widget_destroy(handle);
 	}
 
 	return fontData;
