@@ -422,7 +422,7 @@ public void deselectAll () {
 @Override
 boolean dragDetect (int x, int y, boolean filter, boolean dragOnTimeout, boolean [] consume) {
 	boolean selected = false;
-	if (OS.isX11()) { //Wayland
+	if (OS.isX11()) {
 		if (filter) {
 			long [] path = new long [1];
 			if (GTK.gtk_tree_view_get_path_at_pos (handle, x, y, path, null, null, null)) {
@@ -830,7 +830,7 @@ long gtk_button_press_event (long widget, long event) {
 	}
 
 	if ((state & DRAG_DETECT) != 0 && hooks (SWT.DragDetect) &&
-			!OS.isX11() && eventType == GDK.GDK_BUTTON_PRESS) { // Wayland
+			OS.isWayland() && eventType == GDK.GDK_BUTTON_PRESS) {
 		// check to see if there is another event coming in that is not a double/triple click, this is to prevent Bug 514531
 		long nextEvent = GDK.gdk_event_peek();
 		if (nextEvent == 0) {
@@ -963,7 +963,7 @@ long gtk_button_release_event (long widget, long event) {
 	if (GTK.GTK4) {
 		if (eventGdkResource != gtk_widget_get_surface (handle)) return 0;
 	} else {
-		if (eventGdkResource != GTK.gtk_tree_view_get_bin_window (handle)) return 0;
+		if (eventGdkResource != GTK3.gtk_tree_view_get_bin_window (handle)) return 0;
 	}
 	/*
 	 * Feature in GTK. In multi-select tree view there is a problem with using DnD operations while also selecting multiple items.
@@ -972,7 +972,7 @@ long gtk_button_release_event (long widget, long event) {
 	 * selected, we can give the DnD handling to MOTION-NOTIFY. On release, we can then re-enable the selection method
 	 * and also select the item in the tree by moving the selection logic to release instead. See Bug 503431.
 	 */
-	if ((state & DRAG_DETECT) != 0 && hooks (SWT.DragDetect) && !OS.isX11()) { // Wayland
+	if ((state & DRAG_DETECT) != 0 && hooks (SWT.DragDetect) && OS.isWayland()) {
 		long [] path = new long [1];
 		long selection = GTK.gtk_tree_view_get_selection (handle);
 		// free up the selection function on release.
@@ -1117,7 +1117,7 @@ public boolean isSelected (int index) {
 long paintWindow () {
 	GTK.gtk_widget_realize (handle);
 	// TODO: this function has been removed on GTK4
-	return GTK.gtk_tree_view_get_bin_window (handle);
+	return GTK3.gtk_tree_view_get_bin_window (handle);
 }
 
 @Override
@@ -1711,9 +1711,6 @@ public void setTopIndex (int index) {
 	/*
 	 * Feature in GTK: cache the GtkAdjustment value for future use in
 	 * getTopIndex(). Set topIndex to index.
-	 *
-	 * Use gtk_tree_view_get_view_get_vadjustment for GTK2, GtkScrollable
-	 * doesn't exist on GTK2.
 	 */
 	long vAdjustment = GTK.gtk_scrollable_get_vadjustment (handle);
 	cachedAdjustment = GTK.gtk_adjustment_get_value (vAdjustment);
