@@ -58,7 +58,7 @@ public final class Cursor extends Resource {
 	 *
 	 * @noreference This field is not intended to be referenced by clients.
 	 */
-	public long /*int*/ handle;
+	public long handle;
 
 	boolean isIcon;
 
@@ -117,7 +117,7 @@ Cursor(Device device) {
  */
 public Cursor(Device device, int style) {
 	super(device);
-	long /*int*/ lpCursorName = 0;
+	long lpCursorName = 0;
 	switch (style) {
 		case SWT.CURSOR_HAND: 		lpCursorName = OS.IDC_HAND; break;
 		case SWT.CURSOR_ARROW: 		lpCursorName = OS.IDC_ARROW; break;
@@ -209,7 +209,7 @@ public Cursor(Device device, ImageData source, ImageData mask, int hotspotX, int
 	byte[] maskData = ImageData.convertPad(mask.data, mask.width, mask.height, mask.depth, mask.scanlinePad, 2);
 
 	/* Create the cursor */
-	long /*int*/ hInst = OS.GetModuleHandle(null);
+	long hInst = OS.GetModuleHandle(null);
 	handle = OS.CreateCursor(hInst, hotspotX, hotspotY, source.width, source.height, sourceData, maskData);
 	if (handle == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 	init();
@@ -252,17 +252,16 @@ public Cursor(Device device, ImageData source, int hotspotX, int hotspotY) {
 		hotspotY >= source.height || hotspotY < 0) {
 		SWT.error(SWT.ERROR_INVALID_ARGUMENT);
 	}
-	long /*int*/ hBitmap = 0;
-	long /*int*/ hMask = 0;
+	long hBitmap = 0;
+	long hMask = 0;
 	if (source.maskData == null && source.transparentPixel == -1 && (source.alpha != -1 || source.alphaData != null)) {
 		PaletteData palette = source.palette;
 		PaletteData newPalette = new PaletteData(0xFF00, 0xFF0000, 0xFF000000);
 		ImageData img = new ImageData(source.width, source.height, 32, newPalette);
 		if (palette.isDirect) {
-			ImageData.blit(ImageData.BLIT_SRC,
-				source.data, source.depth, source.bytesPerLine, source.getByteOrder(), 0, 0, source.width, source.height, palette.redMask, palette.greenMask, palette.blueMask,
-				ImageData.ALPHA_OPAQUE, null, 0, 0, 0,
-				img.data, img.depth, img.bytesPerLine, img.getByteOrder(), 0, 0, img.width, img.height, newPalette.redMask, newPalette.greenMask, newPalette.blueMask,
+			ImageData.blit(
+				source.data, source.depth, source.bytesPerLine, source.getByteOrder(), source.width, source.height,    palette.redMask,    palette.greenMask,    palette.blueMask,
+				   img.data,    img.depth,    img.bytesPerLine,    img.getByteOrder(),    img.width,    img.height, newPalette.redMask, newPalette.greenMask, newPalette.blueMask,
 				false, false);
 		} else {
 			RGB[] rgbs = palette.getRGBs();
@@ -277,11 +276,10 @@ public Cursor(Device device, ImageData source, int hotspotX, int hotspotY) {
 				srcGreens[i] = (byte)rgb.green;
 				srcBlues[i] = (byte)rgb.blue;
 			}
-			ImageData.blit(ImageData.BLIT_SRC,
-				source.data, source.depth, source.bytesPerLine, source.getByteOrder(), 0, 0, source.width, source.height, srcReds, srcGreens, srcBlues,
-				ImageData.ALPHA_OPAQUE, null, 0, 0, 0,
-				img.data, img.depth, img.bytesPerLine, img.getByteOrder(), 0, 0, img.width, img.height, newPalette.redMask, newPalette.greenMask, newPalette.blueMask,
-				false, false);
+			ImageData.blit(
+				source.width, source.height,
+				source.data, source.depth, source.bytesPerLine, source.getByteOrder(), srcReds, srcGreens, srcBlues,
+				   img.data,    img.depth,    img.bytesPerLine,    img.getByteOrder(), newPalette.redMask, newPalette.greenMask, newPalette.blueMask);
 		}
 		hBitmap = Image.createDIB(source.width, source.height, 32);
 		if (hBitmap == 0) SWT.error(SWT.ERROR_NO_HANDLES);
@@ -302,7 +300,7 @@ public Cursor(Device device, ImageData source, int hotspotX, int hotspotY) {
 		if (hMask == 0) SWT.error(SWT.ERROR_NO_HANDLES);
 	} else {
 		ImageData mask = source.getTransparencyMask();
-		long /*int*/ [] result = Image.init(this.device, null, source, mask);
+		long [] result = Image.init(this.device, null, source, mask);
 		hBitmap = result[0];
 		hMask = result[1];
 	}
@@ -340,12 +338,12 @@ void destroy () {
 		OS.DestroyIcon(handle);
 	} else {
 		/*
-	 	* The MSDN states that one should not destroy a shared
-	 	* cursor, that is, one obtained from LoadCursor.
-	 	* However, it does not appear to do any harm, so rather
-	 	* than keep track of how a cursor was created, we just
-	 	* destroy them all. If this causes problems in the future,
-	 	* put the flag back in.
+		* The MSDN states that one should not destroy a shared
+		* cursor, that is, one obtained from LoadCursor.
+		* However, it does not appear to do any harm, so rather
+		* than keep track of how a cursor was created, we just
+		* destroy them all. If this causes problems in the future,
+		* put the flag back in.
 		*/
 		OS.DestroyCursor(handle);
 	}
@@ -382,7 +380,7 @@ public boolean equals (Object object) {
  */
 @Override
 public int hashCode () {
-	return (int)/*64*/handle;
+	return (int)handle;
 }
 
 /**
