@@ -14,10 +14,10 @@
 package org.eclipse.swt.widgets;
 
 
-import org.eclipse.swt.internal.win32.*;
 import org.eclipse.swt.*;
-import org.eclipse.swt.graphics.*;
 import org.eclipse.swt.events.*;
+import org.eclipse.swt.graphics.*;
+import org.eclipse.swt.internal.win32.*;
 
 /**
  * Instances of this class are selectable user interface
@@ -30,6 +30,7 @@ import org.eclipse.swt.events.*;
  * <em>minimum</em> and <em>maximum</em> values).
  * </p><p>
  * Typically, sliders will be made up of five areas:
+ * </p>
  * <ol>
  * <li>an arrow button for decrementing the value</li>
  * <li>a page decrement area for decrementing the value by a larger amount</li>
@@ -37,6 +38,7 @@ import org.eclipse.swt.events.*;
  * <li>a page increment area for incrementing the value by a larger amount</li>
  * <li>an arrow button for incrementing the value</li>
  * </ol>
+ * <p>
  * Based on their style, sliders are either <code>HORIZONTAL</code>
  * (which have a left facing button for decrementing the value and a
  * right facing button for incrementing it) or <code>VERTICAL</code>
@@ -74,7 +76,7 @@ import org.eclipse.swt.events.*;
 public class Slider extends Control {
 	int increment, pageIncrement;
 	boolean ignoreFocus;
-	static final long /*int*/ ScrollBarProc;
+	static final long ScrollBarProc;
 	static final TCHAR ScrollBarClass = new TCHAR (0, "SCROLLBAR", true);
 	static {
 		WNDCLASS lpWndClass = new WNDCLASS ();
@@ -156,7 +158,7 @@ public void addSelectionListener (SelectionListener listener) {
 }
 
 @Override
-long /*int*/ callWindowProc (long /*int*/ hwnd, int msg, long /*int*/ wParam, long /*int*/ lParam) {
+long callWindowProc (long hwnd, int msg, long wParam, long lParam) {
 	if (handle == 0) return 0;
 	/*
 	* Feature in Windows.  Windows runs a modal message
@@ -194,6 +196,12 @@ static int checkStyle (int style) {
 	return new Point (width, height);
 }
 
+@Override
+void createHandle () {
+	super.createHandle();
+	maybeEnableDarkSystemTheme();
+}
+
 @Override
 void createWidget () {
 	super.createWidget ();
@@ -481,7 +489,7 @@ public void setPageIncrement (int value) {
 	pageIncrement = value;
 }
 
-boolean SetScrollInfo (long /*int*/ hwnd, int flags, SCROLLINFO info, boolean fRedraw) {
+boolean SetScrollInfo (long hwnd, int flags, SCROLLINFO info, boolean fRedraw) {
 	/*
 	* Feature in Windows.  Using SIF_DISABLENOSCROLL,
 	* SetScrollInfo () can change enabled and disabled
@@ -635,39 +643,39 @@ TCHAR windowClass () {
 }
 
 @Override
-long /*int*/ windowProc () {
+long windowProc () {
 	return ScrollBarProc;
 }
 
 @Override
-LRESULT WM_KEYDOWN (long /*int*/ wParam, long /*int*/ lParam) {
- 	LRESULT result = super.WM_KEYDOWN (wParam, lParam);
- 	if (result != null) return result;
- 	if ((style & SWT.VERTICAL) != 0) return result;
- 	/*
- 	* Bug in Windows.  When a horizontal scroll bar is mirrored,
- 	* the native control does not correctly swap the arrow keys.
- 	* The fix is to swap them before calling the scroll bar window
- 	* proc.
- 	*
- 	* NOTE: This fix is not ideal.  It breaks when the bug is fixed
- 	* in the operating system.
- 	*/
+LRESULT WM_KEYDOWN (long wParam, long lParam) {
+	LRESULT result = super.WM_KEYDOWN (wParam, lParam);
+	if (result != null) return result;
+	if ((style & SWT.VERTICAL) != 0) return result;
+	/*
+	* Bug in Windows.  When a horizontal scroll bar is mirrored,
+	* the native control does not correctly swap the arrow keys.
+	* The fix is to swap them before calling the scroll bar window
+	* proc.
+	*
+	* NOTE: This fix is not ideal.  It breaks when the bug is fixed
+	* in the operating system.
+	*/
 	if ((style & SWT.MIRRORED) != 0) {
-	 	switch ((int)/*64*/wParam) {
-	 		case OS.VK_LEFT:
+		switch ((int)wParam) {
+			case OS.VK_LEFT:
 			case OS.VK_RIGHT: {
 				int key = wParam == OS.VK_LEFT ? OS.VK_RIGHT : OS.VK_LEFT;
-				long /*int*/ code = callWindowProc (handle, OS.WM_KEYDOWN, key, lParam);
-	 			return new LRESULT (code);
-	 		}
-	 	}
+				long code = callWindowProc (handle, OS.WM_KEYDOWN, key, lParam);
+				return new LRESULT (code);
+			}
+		}
 	}
- 	return result;
+	return result;
 }
 
 @Override
-LRESULT WM_LBUTTONDBLCLK (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_LBUTTONDBLCLK (long wParam, long lParam) {
 	/*
 	* Feature in Windows.  Windows uses the WS_TABSTOP
 	* style for the scroll bar to decide that focus
@@ -692,14 +700,14 @@ LRESULT WM_LBUTTONDBLCLK (long /*int*/ wParam, long /*int*/ lParam) {
 	* release the automatic capture.
 	*/
 	if (OS.GetCapture () == handle) OS.ReleaseCapture ();
-	if (!sendMouseEvent (SWT.MouseUp, 1, handle, OS.WM_LBUTTONUP, wParam, lParam)) {
+	if (!sendMouseEvent (SWT.MouseUp, 1, handle, lParam)) {
 		return LRESULT.ZERO;
 	}
 	return result;
 }
 
 @Override
-LRESULT WM_LBUTTONDOWN (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_LBUTTONDOWN (long wParam, long lParam) {
 	/*
 	* Feature in Windows.  Windows uses the WS_TABSTOP
 	* style for the scroll bar to decide that focus
@@ -724,20 +732,20 @@ LRESULT WM_LBUTTONDOWN (long /*int*/ wParam, long /*int*/ lParam) {
 	* release the automatic capture.
 	*/
 	if (OS.GetCapture () == handle) OS.ReleaseCapture ();
-	if (!sendMouseEvent (SWT.MouseUp, 1, handle, OS.WM_LBUTTONUP, wParam, lParam)) {
+	if (!sendMouseEvent (SWT.MouseUp, 1, handle, lParam)) {
 		return LRESULT.ONE;
 	}
 	return result;
 }
 
 @Override
-LRESULT WM_SETFOCUS (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT WM_SETFOCUS (long wParam, long lParam) {
 	if (ignoreFocus) return null;
 	return super.WM_SETFOCUS (wParam, lParam);
 }
 
 @Override
-LRESULT wmScrollChild (long /*int*/ wParam, long /*int*/ lParam) {
+LRESULT wmScrollChild (long wParam, long lParam) {
 
 	/* Do nothing when scrolling is ending */
 	int code = OS.LOWORD (wParam);
