@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -234,9 +234,9 @@ class ShellTab extends Tab {
 		closeAllButton.setLayoutData (gridData);
 
 		/* Add the listeners */
-		createButton.addSelectionListener(widgetSelectedAdapter(e -> createButtonSelected(e)));
+		createButton.addSelectionListener(widgetSelectedAdapter(this::createButtonSelected));
 		closeAllButton.addSelectionListener(widgetSelectedAdapter(e -> closeAllShells ()));
-		SelectionListener decorationButtonListener = widgetSelectedAdapter(event -> decorationButtonSelected(event));
+		SelectionListener decorationButtonListener = widgetSelectedAdapter(this::decorationButtonSelected);
 		noTrimButton.addSelectionListener (decorationButtonListener);
 		noMoveButton.addSelectionListener(decorationButtonListener);
 		closeButton.addSelectionListener (decorationButtonListener);
