@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -1505,7 +1505,7 @@ abstract class Tab {
 	 */
 	void hookListeners (Widget widget) {
 		if (logging) {
-			Listener listener = event -> log (event);
+			Listener listener = this::log;
 			for (int i = 0; i < EVENT_INFO.length; i++) {
 				if (eventsFilter [i]) {
 					widget.addListener (EVENT_INFO[i].type, listener);
