@@ -79,6 +79,7 @@ static int[] colorIds = new int[] {SWT.COLOR_INFO_BACKGROUND,
 		SWT.COLOR_LIST_FOREGROUND,
 		SWT.COLOR_LIST_SELECTION,
 		SWT.COLOR_LIST_SELECTION_TEXT,
+		SWT.COLOR_TEXT_DISABLED_BACKGROUND,
 		SWT.COLOR_TITLE_BACKGROUND,
 		SWT.COLOR_TITLE_BACKGROUND_GRADIENT,
 		SWT.COLOR_TITLE_FOREGROUND,
@@ -88,6 +89,7 @@ static int[] colorIds = new int[] {SWT.COLOR_INFO_BACKGROUND,
 		SWT.COLOR_WIDGET_BACKGROUND,
 		SWT.COLOR_WIDGET_BORDER,
 		SWT.COLOR_WIDGET_DARK_SHADOW,
+		SWT.COLOR_WIDGET_DISABLED_FOREGROUND,
 		SWT.COLOR_WIDGET_FOREGROUND,
 		SWT.COLOR_WIDGET_HIGHLIGHT_SHADOW,
 		SWT.COLOR_WIDGET_LIGHT_SHADOW,
@@ -99,6 +101,7 @@ static String [] colorNames = new String[] {"SWT.COLOR_INFO_BACKGROUND",
 		"SWT.COLOR_LIST_FOREGROUND",
 		"SWT.COLOR_LIST_SELECTION",
 		"SWT.COLOR_LIST_SELECTION_TEXT",
+		"SWT.COLOR_TEXT_DISABLED_BACKGROUND",
 		"SWT.COLOR_TITLE_BACKGROUND",
 		"SWT.COLOR_TITLE_BACKGROUND_GRADIENT",
 		"SWT.COLOR_TITLE_FOREGROUND",
@@ -108,6 +111,7 @@ static String [] colorNames = new String[] {"SWT.COLOR_INFO_BACKGROUND",
 		"SWT.COLOR_WIDGET_BACKGROUND",
 		"SWT.COLOR_WIDGET_BORDER",
 		"SWT.COLOR_WIDGET_DARK_SHADOW",
+		"SWT.COLOR_WIDGET_DISABLED_FOREGROUND",
 		"SWT.COLOR_WIDGET_FOREGROUND",
 		"SWT.COLOR_WIDGET_HIGHLIGHT_SHADOW",
 		"SWT.COLOR_WIDGET_LIGHT_SHADOW",
