@@ -111,11 +111,10 @@ public class Snippet288 {
 						/* Fill with the background color before drawing. */
 						Color bgColor = null;
 						if (useGIFBackground && loader[i].backgroundPixel != -1) {
-							bgColor = new Color(display, imageData.palette.getRGB(loader[i].backgroundPixel));
+							bgColor = new Color(imageData.palette.getRGB(loader[i].backgroundPixel));
 						}
 						gc.setBackground(bgColor != null ? bgColor : shellBackground);
 						gc.fillRectangle(imageData.x, imageData.y, imageData.width, imageData.height);
-						if (bgColor != null) bgColor.dispose();
 						break;
 					default:
 						/* Restore the previous image before drawing. */
