@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -61,7 +61,7 @@ public class Snippet354 {
 		display.addFilter(SWT.KeyDown, keyDownFilter);
 		display.addFilter(SWT.KeyUp, keyDownFilter);
 
-		ArmListener armListener = e -> System.out.println(e);
+		ArmListener armListener = System.out::println;
 
 		Menu systemMenu = display.getSystemMenu();
 		if (systemMenu != null) {
