@@ -21,17 +21,17 @@ package org.eclipse.swt.snippets;
  *
  * @since 3.107
  */
-import org.eclipse.swt.SWT;
-import org.eclipse.swt.custom.StyledText;
-import org.eclipse.swt.layout.FillLayout;
-import org.eclipse.swt.widgets.Display;
-import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.*;
+import org.eclipse.swt.custom.*;
+import org.eclipse.swt.layout.*;
+import org.eclipse.swt.widgets.*;
 
 public class Snippet368 {
 
 	public static void main(String[] args) throws Exception {
 		Display display = new Display();
 		Shell shell = new Shell(display);
+		shell.setText("Snippet 368");
 		shell.setLayout(new FillLayout());
 		shell.setText("Customize line spacing provider");
 
