@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -35,8 +35,8 @@ public static void main (String [] args) {
 	String filterPath = "/";
 	String platform = SWT.getPlatform();
 	if (platform.equals("win32")) {
-		filterNames = new String [] {"Image Files", "All Files (*.*)"};
-		filterExtensions = new String [] {"*.gif;*.png;*.bmp;*.jpg;*.jpeg;*.tiff", "*.*"};
+		filterNames = new String [] {"All Files (*)"};
+		filterExtensions = new String [] {"*"};
 		filterPath = "c:\\";
 	}
 	dialog.setFilterNames (filterNames);
