@@ -15,7 +15,6 @@ package org.eclipse.swt.tests.junit;
 
 
 import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
@@ -122,7 +121,7 @@ public void test_setVisibility_and_sizing() {
 }
 
 @Test
-public void test_setFocus_toChild_afterOpen() throws InterruptedException {
+public void test_setFocus_toChild_afterOpen() {
 	if (SwtTestUtil.isCocoa) {
 		//TODO Fix Cocoa failure.
 		if (SwtTestUtil.verbose) {
@@ -131,16 +130,13 @@ public void test_setFocus_toChild_afterOpen() throws InterruptedException {
 		return;
 	}
 	Text focusChild = new Text(composite, SWT.NONE);
-	shell.open();
-	// Wait for the shell to become active
-	processEvents(500, () -> shell.getDisplay().getActiveShell() == shell);
-	assertEquals(shell, shell.getDisplay().getActiveShell());
+	SwtTestUtil.waitShellActivate(shell::open, shell);
 	composite.setFocus();
 	assertTrue("First child widget should have focus", focusChild.isFocusControl());
 }
 
 @Test
-public void test_setFocus_toChild_beforeOpen() throws InterruptedException {
+public void test_setFocus_toChild_beforeOpen() {
 	if (SwtTestUtil.isCocoa) {
 		//TODO Fix Cocoa failure.
 		if (SwtTestUtil.verbose) {
@@ -150,15 +146,12 @@ public void test_setFocus_toChild_beforeOpen() throws InterruptedException {
 	}
 	Text focusChild = new Text(composite, SWT.NONE);
 	composite.setFocus();
-	shell.open();
-	// Wait for the shell to become active
-	processEvents(500, () -> shell.getDisplay().getActiveShell() == shell);
-	assertEquals(shell, shell.getDisplay().getActiveShell());
+	SwtTestUtil.waitShellActivate(shell::open, shell);
 	assertTrue("First child widget should have focus", focusChild.isFocusControl());
 }
 
 @Test
-public void test_setFocus_withInvisibleChild() throws InterruptedException {
+public void test_setFocus_withInvisibleChild() {
 	final AtomicReference<Boolean> wasSetFocusCalledOnInvisibleChildWidget = new AtomicReference<>(false);
 	Composite invisibleChildWidget = new Composite(composite, SWT.NONE) {
 		@Override
@@ -168,17 +161,14 @@ public void test_setFocus_withInvisibleChild() throws InterruptedException {
 		}
 	};
 	invisibleChildWidget.setVisible(false);
-	shell.open();
-	// Wait for the shell to become active
-	processEvents(500, () -> shell.getDisplay().getActiveShell() == shell);
-	assertEquals(shell, shell.getDisplay().getActiveShell());
+	SwtTestUtil.waitShellActivate(shell::open, shell);
 
 	composite.setFocus();
 	assertFalse("Composite should not try to set focus on invisible child", wasSetFocusCalledOnInvisibleChildWidget.get());
 }
 
 @Test
-public void test_setFocus_withVisibleAndInvisibleChild() throws InterruptedException {
+public void test_setFocus_withVisibleAndInvisibleChild() {
 	final AtomicReference<Boolean> wasSetFocusCalledOnInvisibleChildWidget = new AtomicReference<>(false);
 	Composite invisibleChildWidget = new Composite(composite, SWT.NONE) {
 		@Override
@@ -189,10 +179,7 @@ public void test_setFocus_withVisibleAndInvisibleChild() throws InterruptedExcep
 	};
 	invisibleChildWidget.setVisible(false);
 	Composite visibleChildWidget = new Composite(composite, SWT.NONE);
-	shell.open();
-	// Wait for the shell to become active
-	processEvents(500, () -> shell.getDisplay().getActiveShell() == shell);
-	assertEquals(shell, shell.getDisplay().getActiveShell());
+	SwtTestUtil.waitShellActivate(shell::open, shell);
 
 	composite.setFocus();
 	assertFalse("Composite should not try to set focus on invisible child", wasSetFocusCalledOnInvisibleChildWidget.get());
