@@ -19,6 +19,7 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
 import static org.junit.Assert.assertTrue;
 
 import java.io.IOException;
@@ -34,10 +35,12 @@ import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.graphics.Region;
 import org.eclipse.swt.layout.FillLayout;
+import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Shell;
+import org.eclipse.swt.widgets.Text;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
@@ -921,4 +924,79 @@ public void test_bug558652_scrollBarNPE() {
 	}
 }
 
+@Test
+public void test_Issue450_NoShellActivateOnSetFocus() {
+	final String key = "org.eclipse.swt.internal.activateShellOnForceFocus";
+	final String prevKey = System.getProperty(key, null);
+	System.setProperty(key, "false");
+	try {
+		Display display = shell.getDisplay();
+
+		// First shell
+		final Shell shell1 = new Shell(shell);
+		shell1.setText("shell1");
+		shell1.setLayout(new GridLayout()); // without layout the text controls will have zero size
+		final Text text11 = new Text(shell1, SWT.BORDER | SWT.SINGLE);
+		final Text text12 = new Text(shell1, SWT.BORDER | SWT.SINGLE);
+
+		// Second shell
+		final Shell shell2 = new Shell(shell);
+		shell2.setText("shell2");
+		shell2.setLayout(new GridLayout()); // without layout the text controls will have zero size
+		final Text text21 = new Text(shell2, SWT.BORDER | SWT.SINGLE);
+		final Text text22 = new Text(shell2, SWT.BORDER | SWT.SINGLE);
+
+		// System.out.println("open 1st shell");
+		SwtTestUtil.waitShellActivate(shell1::open, shell1);
+		assertSame("expecting the 1st shell to be activated", display.getActiveShell(), shell1);
+		assertTrue("expecting the 1st text field to be focused in the 1st shell", text11.isFocusControl());
+
+		// System.out.println("open 2nd shell");
+		SwtTestUtil.waitShellActivate(shell2::open, shell2);
+		assertSame("expecting the 2nd shell to be activated", display.getActiveShell(), shell2);
+		assertTrue("expecting the 1st text field in 2nd shell to be focused", text21.isFocusControl());
+
+		// System.out.println("setting focus to 2nd text field in 1st (unactivated) shell");
+		text12.setFocus();
+		assertSame("expecting the 2nd shell to remain activated", display.getActiveShell(), shell2);
+
+		// System.out.println("activating 1st shell");
+		// Fails here for Linux (21.04+ or Manjaro starting ~July 2023)? Check Bug 575712
+		// workaround: set env-var GDK_BACKEND=x11
+		SwtTestUtil.waitShellActivate(shell1::setActive, shell1);
+		assertSame("expecting the 1st shell to be activated", display.getActiveShell(), shell1);
+		assertTrue("expecting the the 1st shell to have remembered the previous setFocus and with the shell activation setting it to the 2nd text field", text12.isFocusControl());
+
+		// System.out.println("disposing 1st shell");
+		SwtTestUtil.waitShellActivate(
+			() -> {
+				shell1.dispose();
+				// on macOS, disposing a Shell sometimes doesn't activate the other Shell.
+				// Not reproducible on my machine. Not reproducible on GitHub builder.
+				// Only seems to occur on Eclipse builder, not sure what's different there.
+				// Anyways, this is out of scope of this test, so just ask to activate.
+				if (SwtTestUtil.isCocoa) shell2.forceActive();
+			},
+			shell2
+		);
+		assertSame("expecting the 2nd shell to be activated after the 1st, active has been disposed", display.getActiveShell(), shell2);
+		assertTrue("expecting the 1st text field in the 2nd shell to still have the focus because it hasn't been changed", text21.isFocusControl());
+
+		// System.out.println("setting the focus to the 2nd text field");
+		text22.setFocus();
+		assertSame("expecting the 2nd shell to remain activated", display.getActiveShell(), shell2);
+		assertTrue("expecting the 2nd text field to have received the focus", text22.isFocusControl());
+
+		// System.out.println("disposing the 2nd shell, too");
+		shell2.dispose();
+	}
+	finally {
+		if (prevKey != null) {
+			System.setProperty(key, prevKey);
+		}
+		else {
+			System.getProperties().remove(key);
+		}
+	}
+}
 }
